@@ -18,66 +18,48 @@
 
 #include <config.h>
 
-#include <errno.h>
-#include <pthread.h>
-#include <stdio.h>
-#include <signal.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <fcntl.h>
+#include "application.h"
+#include "options.h"
+#include "dict.h"
 
-#include <qstrlist.h>
 #include <qregexp.h>
-#include <qsocketnotifier.h>
-#include <qcolor.h>
-#include <qlist.h>
+#include <qtextcodec.h>
 
 #include <klocale.h>
 #include <kdebug.h>
 #include <kmessagebox.h>
-#include <kapp.h>
 #include <kmdcodec.h>
 #include <kextsock.h>
 #include <ksocks.h>
 
-#include "application.h"
-#include "options.h"
-#include "dict.h"
+#include <errno.h>
+#include <unistd.h>
+#include <fcntl.h>
+#include <signal.h>
+#include <stdlib.h>
 
 //********* JobData ******************************************
 
 
 JobData::JobData(QueryType Ntype,bool NnewServer,QString const& Nserver,int Nport,
-                 int NidleHold, int Ntimeout, int NpipeSize, bool NAuthEnabled,
+                 int NidleHold, int Ntimeout, int NpipeSize, QString const& Nencoding, bool NAuthEnabled,
                  QString const& Nuser, QString const& Nsecret, unsigned int NheadLayout)
-  : type(Ntype), error(ErrNoErr), canceled(false), numFetched(0), result(0L),
-    matches(0L), defines(0L), newServer(NnewServer),server(Nserver), port(Nport),
-    timeout(Ntimeout), pipeSize(NpipeSize), idleHold(NidleHold), authEnabled(NAuthEnabled),
+  : type(Ntype), error(ErrNoErr), canceled(false), numFetched(0), newServer(NnewServer),server(Nserver), port(Nport),
+    timeout(Ntimeout), pipeSize(NpipeSize), idleHold(NidleHold), encoding(Nencoding), authEnabled(NAuthEnabled),
     user(Nuser), secret(Nsecret), headLayout(NheadLayout)
 {}
 
 
-JobData::~JobData()
-{
-  if (result)
-    delete result;
-  if (matches)
-    delete matches;
-  if (defines)
-    delete defines;
-}
-
-
 //********* DictAsyncClient *************************************
 
 DictAsyncClient::DictAsyncClient(int NfdPipeIn, int NfdPipeOut)
-: job(0L), resultSizeInc(10000), inputSize(10000), fdPipeIn(NfdPipeIn),
+: job(0L), inputSize(10000), fdPipeIn(NfdPipeIn),
   fdPipeOut(NfdPipeOut), tcpSocket(-1), idleHold(0)
 {
   input = new char[inputSize];
 }
 
- 
+
 DictAsyncClient::~DictAsyncClient()
 {
   if (-1!=tcpSocket)
@@ -89,7 +71,7 @@ DictAsyncClient::~DictAsyncClient()
 void* DictAsyncClient::startThread(void* pseudoThis)
 {
   DictAsyncClient* newthis = (DictAsyncClient*) (pseudoThis);
-  
+
   if (0!=pthread_setcanceltype(PTHREAD_CANCEL_ENABLE,NULL))
     qWarning("pthread_setcanceltype failed!");
   if (0!= pthread_setcanceltype(PTHREAD_CANCEL_ASYNCHRONOUS,NULL))
@@ -107,7 +89,7 @@ void DictAsyncClient::insertJob(JobData *newJob)
   if (!job)        // don't overwrite existing job pointer
     job = newJob;
 }
-    
+
 
 void DictAsyncClient::removeJob()
 {
@@ -121,7 +103,7 @@ void DictAsyncClient::waitForWork()
   timeval tv;
   int selectRet;
   char buf;
-  
+
   while (true) {
     if (tcpSocket != -1) {  // we are connected, hold the connection for xx secs
       FD_ZERO(&fdsR);
@@ -150,11 +132,8 @@ void DictAsyncClient::waitForWork()
     if (job) {
       if ((tcpSocket!=-1)&&(job->newServer))
         doQuit();
-      
-      job->result = new char[resultSizeInc];
-      job->result[0] = 0;
-      resultPos = 0;
-      resultSize = resultSizeInc;
+
+      codec = QTextCodec::codecForName(job->encoding.latin1());
       input[0] = 0;                 //terminate string
       thisLine = input;
       nextLine = input;
@@ -164,7 +143,7 @@ void DictAsyncClient::waitForWork()
 
       if (tcpSocket==-1)
         openConnection();
-      
+
       if (tcpSocket!=-1) {        // connection is ready
         switch (job->type) {
         case JobData::TDefine :
@@ -202,62 +181,59 @@ void DictAsyncClient::waitForWork()
 
 void DictAsyncClient::define()
 {
-  QCString command;
+  QString command;
 
-  job->defines = new QStrList;
-  
-  for (unsigned int i=0;i<job->databases.count();i++) {
+  job->defines.clear();
+  QStringList::iterator it;
+  for (it = job->databases.begin(); it != job->databases.end(); ++it) {
     command = "define ";
-    command += job->databases.at(i);
+    command += *it;
     command += " \"";
     command += job->query;
     command += "\"\r\n";
-    job->defines->append(command);
+    job->defines.append(command);
   }
-  
+
   if (!getDefinitions())
     return;
-  
+
   if (job->numFetched == 0) {
     job->strategy = ".";
     if (!match())
       return;
-    resultPos = 0;
+    job->result = QString::null;
     if (job->numFetched == 0) {
       resultAppend("<body>\n<p class=\"heading\">\n");
-      resultAppend((i18n("No definitions found for \'%1'!").arg(QString::fromUtf8(job->query))).utf8().data());
+      resultAppend(i18n("No definitions found for \'%1'.").arg(job->query));
       resultAppend("</p>\n</html></body>");
     } else {
       // html header...
       resultAppend("<body>\n<p class=\"heading\">\n");
-      resultAppend((i18n("No definitions found for \'%1\', perhaps you mean:").arg(QString::fromUtf8(job->query))).utf8().data());
+      resultAppend(i18n("No definitions found for \'%1\'. Perhaps you mean:").arg(job->query));
       resultAppend("</p>\n<table width=\"100%\" cols=2>\n");
 
-      QCString lastDb;
-      do {
-        char *s = strchr(job->matches->getFirst(),' ');
-        if (s) {
-          s[0] = 0;
-          if (lastDb != job->matches->getFirst()) {
-            if (lastDb.length())
+      QString lastDb;
+      QStringList::iterator it;
+      for (it = job->matches.begin(); it != job->matches.end(); ++it) {
+        int pos = (*it).find(' ');
+        if (pos != -1) {
+          if (lastDb != (*it).left(pos)) {
+            if (lastDb.length() > 0)
               resultAppend("</pre></td></tr>\n");
-            lastDb = job->matches->getFirst();
+            lastDb = (*it).left(pos);
             resultAppend("<tr valign=top><td width=25%><pre><b>");
             resultAppend(lastDb);
             resultAppend(":</b></pre></td><td width=75%><pre>");
           }
-          s++;
-          if (strlen(s)>2) {
-            s++;
+          if ((*it).length() > (unsigned int)pos+2) {
             resultAppend("<a href=\"http://define/");
-            resultAppend(s,strlen(s)-1);
+            resultAppend((*it).mid(pos+2, (*it).length()-pos-3));
             resultAppend("\">");
-            resultAppend(s,strlen(s)-1);
+            resultAppend((*it).mid(pos+2, (*it).length()-pos-3));
             resultAppend("</a> ");
           }
         }
-        job->matches->removeFirst();
-      } while (job->matches->count());
+      }
       resultAppend("\n</pre></td></tr></table>\n</body></html>");
       job->numFetched = 0;
     }
@@ -265,10 +241,10 @@ void DictAsyncClient::define()
 }
 
 
-QCString htmlString(const QCString &raw)
+QString htmlString(const QString &raw)
 {
   unsigned int len=raw.length();
-  QCString ret(len);
+  QString ret;
 
   for (unsigned int i=0; i<len; i++) {
     switch (raw[i]) {
@@ -283,19 +259,21 @@ QCString htmlString(const QCString &raw)
 }
 
 
-QCString generateDefineLink(const QCString &raw)
+QString generateDefineLink(const QString &raw)
 {
   QRegExp http("http://[^\\s<>()\"|\\[\\]{}]+");
   QRegExp ftp("ftp://[^\\s<>()\"|\\[\\]{}]+");
   int matchPos=0, matchLen=0;
   bool httpMatch=false;
-  QCString ret;
+  QString ret;
 
-  matchPos = http.match(raw, 0, &matchLen);
+  matchPos = http.search(raw);
+  matchLen = http.matchedLength();
   if (-1 != matchPos) {
     httpMatch = true;
   } else {
-    matchPos = ftp.match(raw, 0, &matchLen);
+    matchPos = ftp.search(raw);
+    matchLen = ftp.matchedLength();
     httpMatch = false;
   }
 
@@ -335,14 +313,15 @@ bool DictAsyncClient::getDefinitions()
   // html header...
   resultAppend("<body>\n");
 
-  while (job->defines->count()>0) {
+  while (job->defines.count()>0) {
     defCount = 0;
     cmdBuffer = "";
     do {
-      cmdBuffer += job->defines->at(0);
+      QStringList::iterator it = job->defines.begin();
+      cmdBuffer += codec->fromUnicode(*it);
       defCount++;
-      job->defines->removeFirst();
-    } while ((job->defines->count()>0)&&((int)cmdBuffer.length()<job->pipeSize));
+      job->defines.remove(it);
+    } while ((job->defines.count()>0)&&((int)cmdBuffer.length()<job->pipeSize));
 
     if (!sendBuffer())
       return false;
@@ -373,19 +352,19 @@ bool DictAsyncClient::getDefinitions()
               }
             } else {
               job->error = JobData::ErrServerError;
-              resultPos = 0;
+              job->result = QString::null;
               resultAppend(thisLine);
               doQuit();
               return false;
             }
 
-            int oldResPos = resultPos;
+            int oldResPos = job->result.length();
 
             if (((job->headLayout<2)&&(lastDb!=db))||(job->headLayout==2)) {
               lastDb = db;
               resultAppend("<p class=\"heading\">\n");
               if (dbdes)
-                resultAppend(dbdes,strlen(dbdes)-1);
+                resultAppend(codec->toUnicode(dbdes,strlen(dbdes)-1));
               resultAppend(" [<a href=\"http://dbinfo/");
               resultAppend(db);
               resultAppend("\">");
@@ -415,25 +394,25 @@ bool DictAsyncClient::getDefinitions()
                 if (!bracketBuff.isEmpty()) {
                   s = strchr(line,'}');
                   if (!s)
-                    resultAppend(bracketBuff);
+                    resultAppend(bracketBuff.data());
                   else {
                     s[0] = 0;
                     bracketBuff.remove(0,1);       // remove '{'
                     bracketBuff += line;
                     line = s+1;
-                    resultAppend(generateDefineLink(bracketBuff));
+                    resultAppend(generateDefineLink(codec->toUnicode(bracketBuff)));
                   }
                   bracketBuff = "";
                 }
                 s = strchr(line,'{');
                 while (s) {
-                  resultAppend(line,s-line);
+                  resultAppend(htmlString(codec->toUnicode(line,s-line)));
                   line = s;
                   s = strchr(line,'}');
                   if (s) {
                     s[0] = 0;
                     line++;
-                    resultAppend(generateDefineLink(line));
+                    resultAppend(generateDefineLink(codec->toUnicode(line)));
                     line = s+1;
                     s = strchr(line,'{');
                   } else {
@@ -444,16 +423,15 @@ bool DictAsyncClient::getDefinitions()
                   }
                 }
                 if (line) {
-                  resultAppend(htmlString(line));
-                  resultAppend('\n');
+                  resultAppend(htmlString(codec->toUnicode(line)));
+                  resultAppend("\n");
                 }
               }
             }
             resultAppend("</p></pre>\n");
 
-            context.finalize();
             if (hashList.find(context.hexDigest())>=0)         // duplicate??
-              resultPos = oldResPos;              // delete the whole definition
+              job->result.truncate(oldResPos);              // delete the whole definition
             else {
               hashList.append(context.hexDigest());
               job->numFetched++;
@@ -483,24 +461,23 @@ bool DictAsyncClient::getDefinitions()
 
 bool DictAsyncClient::match()
 {
-  job->matches = new QStrList();
-  int todo = job->databases.count();
+  QStringList::iterator it = job->databases.begin();
   int response;
   cmdBuffer = "";
 
-  while (todo) {
+  while (it != job->databases.end()) {
     int send = 0;
     do {
       cmdBuffer += "match ";
-      cmdBuffer += job->databases.at(job->databases.count()-todo);
+      cmdBuffer += codec->fromUnicode(*(it));
       cmdBuffer += " ";
-      cmdBuffer += job->strategy;
+      cmdBuffer += codec->fromUnicode(job->strategy);
       cmdBuffer += " \"";
-      cmdBuffer += job->query;
+      cmdBuffer += codec->fromUnicode(job->query);
       cmdBuffer += "\"\r\n";
       send++;
-      todo--;
-    } while ((todo>0)&&((int)cmdBuffer.length()<job->pipeSize));
+      ++it;
+    } while ((it != job->databases.end())&&((int)cmdBuffer.length()<job->pipeSize));
 
     if (!sendBuffer())
       return false;
@@ -526,7 +503,7 @@ bool DictAsyncClient::match()
           }
           if (!matchDone) {
             job->numFetched++;
-            job->matches->append(line);
+            job->matches.append(codec->toUnicode(line));
           }
         }
         if (!nextResponseOk(250))   // match: "250 ok ..."
@@ -555,7 +532,7 @@ void DictAsyncClient::showDatabases()
 
   // html header...
   resultAppend("<body>\n<p class=\"heading\">\n");
-  resultAppend(i18n("Available Databases:").utf8().data());
+  resultAppend(i18n("Available Databases:"));
   resultAppend("\n</p>\n<table width=\"100%\" cols=2>\n");
 
   bool done(false);
@@ -575,9 +552,9 @@ void DictAsyncClient::showDatabases()
       resultAppend("<tr valign=top><td width=25%><pre><a href=\"http://dbinfo/");
       char *space = strchr(line,' ');
       if (space) {
-        resultAppend(line,space-line);
+        resultAppend(codec->toUnicode(line,space-line));
         resultAppend("\">");
-        resultAppend(line,space-line);
+        resultAppend(codec->toUnicode(line,space-line));
         resultAppend("</a></pre></td><td width=75%><pre>");
         line = space+1;
         if (line[0]=='"') {
@@ -603,7 +580,7 @@ void DictAsyncClient::showDatabases()
 void DictAsyncClient::showDbInfo()
 {
   cmdBuffer = "show info ";
-  cmdBuffer += job->query;
+  cmdBuffer += codec->fromUnicode(job->query);
   cmdBuffer += "\r\n";
 
   if (!sendBuffer())
@@ -614,7 +591,7 @@ void DictAsyncClient::showDbInfo()
 
   // html header...
   resultAppend("<body>\n<p class=\"heading\">\n");
-  resultAppend((i18n("Database Information [%1]:").arg(QString::fromUtf8(job->query))).utf8().data());
+  resultAppend(i18n("Database Information [%1]:").arg(job->query));
   resultAppend("</p>\n<pre><p class=\"definition\">\n");
 
   bool done(false);
@@ -632,7 +609,7 @@ void DictAsyncClient::showDbInfo()
     }
     if (!done) {
       resultAppend(line);
-      resultAppend('\n');
+      resultAppend("\n");
     }
   }
 
@@ -655,7 +632,7 @@ void DictAsyncClient::showStrategies()
 
   // html header...
   resultAppend("<body>\n<p class=\"heading\">\n");
-  resultAppend(i18n("Available Strategies:").utf8().data());
+  resultAppend(i18n("Available Strategies:"));
   resultAppend("\n</p>\n<table width=\"100%\" cols=2>\n");
 
   bool done(false);
@@ -675,7 +652,7 @@ void DictAsyncClient::showStrategies()
       resultAppend("<tr valign=top><td width=25%><pre>");
       char *space = strchr(line,' ');
       if (space) {
-        resultAppend(line,space-line);
+        resultAppend(codec->toUnicode(line,space-line));
         resultAppend("</pre></td><td width=75%><pre>");
         line = space+1;
         if (line[0]=='"') {
@@ -710,9 +687,9 @@ void DictAsyncClient::showInfo()
 
   // html header...
   resultAppend("<body>\n<p class=\"heading\">\n");
-  resultAppend(i18n("Server Information:").utf8().data());
+  resultAppend(i18n("Server Information:"));
   resultAppend("\n</p>\n<pre><p class=\"definition\">\n");
-  
+
   bool done(false);
   char *line;
   while (!done) {
@@ -728,7 +705,7 @@ void DictAsyncClient::showInfo()
     }
     if (!done) {
       resultAppend(line);
-      resultAppend('\n');
+      resultAppend("\n");
     }
   }
 
@@ -765,7 +742,7 @@ void DictAsyncClient::update()
     if (!done) {
       char *space = strchr(line,' ');
       if (space) space[0] = 0;  // terminate string, hack ;-)
-      job->strategies.append(line);
+      job->strategies.append(codec->toUnicode(line));
     }
   }
 
@@ -790,7 +767,7 @@ void DictAsyncClient::update()
     if (!done) {
       char *space = strchr(line,' ');
       if (space) space[0] = 0;  // terminate string, hack ;-)
-      job->databases.append(line);
+      job->databases.append(codec->toUnicode(line));
     }
   }
 
@@ -815,14 +792,14 @@ void DictAsyncClient::openConnection()
     if (ks.status() == IO_LookupError)
       job->error = JobData::ErrBadHost;
     else if (ks.status() == IO_ConnectError) {
-      resultPos = 0;
-      resultAppend(KExtendedSocket::strError(ks.status(), errno).local8Bit().data());
+      job->result = QString::null;
+      resultAppend(KExtendedSocket::strError(ks.status(), errno));
       job->error = JobData::ErrConnect;
     } else if (ks.status() == IO_TimeOutError)
       job->error = JobData::ErrTimeout;
     else {
-      resultPos = 0;
-      resultAppend(KExtendedSocket::strError(ks.status(), errno).local8Bit().data());
+      job->result = QString::null;
+      resultAppend(KExtendedSocket::strError(ks.status(), errno));
       job->error = JobData::ErrCommunication;
     }
 
@@ -834,11 +811,11 @@ void DictAsyncClient::openConnection()
 
   if (!nextResponseOk(220))    // connect: "220 text capabilities msg-id"
     return;
-  
+
   cmdBuffer = "client \"Kdict ";
   cmdBuffer += KDICT_VERSION;
   cmdBuffer += "\"\r\n";
-  
+
   if (job->authEnabled)
     if (strstr(thisLine,"auth")) {    // skip auth if not supported
       char *msgId = strrchr(thisLine,'<');
@@ -851,8 +828,7 @@ void DictAsyncClient::openConnection()
 
       KMD5 context;
       context.update(QCString(msgId));
-      context.update(job->secret);
-      context.finalize();
+      context.update(job->secret.local8Bit());
 
       cmdBuffer += "auth " + job->user.local8Bit() + " ";
       cmdBuffer += context.hexDigest();
@@ -864,7 +840,7 @@ void DictAsyncClient::openConnection()
 
   if (!nextResponseOk(250))    // client: "250 ok ..."
     return;
-  
+
   if (job->authEnabled)
     if (!nextResponseOk(230))   // auth: "230 Authentication successful"
       return;
@@ -922,7 +898,7 @@ bool DictAsyncClient::waitForRead()
 
   if (ret == -1) {     // select failed
     if (job) {
-      resultPos = 0;
+      job->result = QString::null;
       resultAppend(strerror(errno));
       job->error = JobData::ErrCommunication;
     }
@@ -942,8 +918,8 @@ bool DictAsyncClient::waitForRead()
     }
     if (FD_ISSET(tcpSocket,&fdsE)||FD_ISSET(fdPipeIn,&fdsE)) {  // broken pipe, etc
       if (job) {
-        resultPos = 0;
-        resultAppend(i18n("The connection is broken.").utf8().data());
+        job->result = QString::null;
+        resultAppend(i18n("The connection is broken."));
         job->error = JobData::ErrCommunication;
       }
       closeSocket();
@@ -954,7 +930,7 @@ bool DictAsyncClient::waitForRead()
   }
 
   if (job) {
-    resultPos = 0;
+    job->result = QString::null;
     job->error = JobData::ErrCommunication;
   }
   closeSocket();
@@ -985,7 +961,7 @@ bool DictAsyncClient::waitForWrite()
 
   if (ret == -1) {     // select failed
     if (job) {
-      resultPos = 0;
+      job->result = QString::null;
       resultAppend(strerror(errno));
       job->error = JobData::ErrCommunication;
     }
@@ -1005,8 +981,8 @@ bool DictAsyncClient::waitForWrite()
     }
     if (FD_ISSET(tcpSocket,&fdsR)||FD_ISSET(tcpSocket,&fdsE)||FD_ISSET(fdPipeIn,&fdsE)) {  // broken pipe, etc
       if (job) {
-        resultPos = 0;
-        resultAppend(i18n("The connection is broken.").utf8().data());
+        job->result = QString::null;
+        resultAppend(i18n("The connection is broken."));
         job->error = JobData::ErrCommunication;
       }
       closeSocket();
@@ -1016,7 +992,7 @@ bool DictAsyncClient::waitForWrite()
       return true;
   }
   if (job) {
-    resultPos = 0;
+    job->result = QString::null;
     job->error = JobData::ErrCommunication;
   }
   closeSocket();
@@ -1031,10 +1007,10 @@ void DictAsyncClient::clearPipe()
   timeval tv;
   int selectRet;
   char buf;
-  
+
   tv.tv_sec = 0;
   tv.tv_usec = 0;
-  do { 
+  do {
     FD_ZERO(&fdsR);
     FD_SET(fdPipeIn,&fdsR);
     if (1==(selectRet=select(FD_SETSIZE,&fdsR,NULL,NULL,&tv)))
@@ -1049,14 +1025,14 @@ bool DictAsyncClient::sendBuffer()
   int ret;
   int todo = cmdBuffer.length();
   int done = 0;
-  
+
   while (todo > 0) {
     if (!waitForWrite())
       return false;
     ret = KSocks::self()->write(tcpSocket,&cmdBuffer.data()[done],todo);
     if (ret <= 0) {
       if (job) {
-        resultPos = 0;
+        job->result = QString::null;
         resultAppend(strerror(errno));
         job->error = JobData::ErrCommunication;
       }
@@ -1099,10 +1075,10 @@ bool DictAsyncClient::getNextLine()
     do {
       received = KSocks::self()->read(tcpSocket, inputEnd, inputSize-(inputEnd-input)-1);
     } while ((received<0)&&(errno==EINTR));       // don't get tricked by signals
-    
+
     if (received <= 0) {
-      resultPos = 0;
-      resultAppend(i18n("The connection is broken.").utf8().data());
+      job->result = QString::null;
+      resultAppend(i18n("The connection is broken."));
       job->error = JobData::ErrCommunication;
       closeSocket();
       return false;
@@ -1145,8 +1121,8 @@ void DictAsyncClient::handleErrors()
   int len = strlen(thisLine);
   if (len>80)
     len = 80;
-  resultPos = 0;
-  resultAppend(thisLine,len);
+  job->result = QString::null;
+  resultAppend(codec->toUnicode(thisLine,len));
 
   switch (strtol(thisLine,0L,0)) {
     case 420:
@@ -1186,41 +1162,18 @@ void DictAsyncClient::handleErrors()
 
 void DictAsyncClient::resultAppend(const char* str)
 {
-  resultAppend(str,strlen(str));
+  if (job)
+    job->result += codec->toUnicode(str);
 }
 
 
-void DictAsyncClient::resultAppend(const char* str,unsigned int length)
+void DictAsyncClient::resultAppend(QString str)
 {
-  if (length >= resultSizeInc)  // just in case, should never happen
-    length = resultSizeInc-1;
-  if (resultPos+length>=resultSize) {    // we must expand the result string
-    resultSize += resultSizeInc;
-    char *newresult = new char[resultSize];
-    memcpy(newresult,job->result,resultPos);
-    delete job->result;
-    job->result = newresult;
-  }
-  memcpy(&job->result[resultPos],str,length);
-  resultPos += length;
-  job->result[resultPos] = 0;        // terminate string;
+  if (job)
+    job->result += str;
 }
 
 
-void DictAsyncClient::resultAppend(char chr)
-{
-  if (resultPos+1>=resultSize) {    // we must expand the result string
-    resultSize += resultSizeInc;
-    char *newresult = new char[resultSize];
-    memcpy(newresult,job->result,resultPos);
-    delete job->result;
-    job->result = newresult;
-  }
-  job->result[resultPos] = chr;
-  resultPos++;
-  job->result[resultPos] = 0;        // terminate string;
-}
-
 
 //********* DictInterface ******************************************
 
@@ -1229,27 +1182,27 @@ DictInterface::DictInterface()
 {
   if (::pipe(fdPipeIn ) == -1 ) {
     perror( "Creating in pipe" );
-    KMessageBox::error(global->topLevel, i18n("Internal error:\nFailed to open pipes for internal communcation!"));
+    KMessageBox::error(global->topLevel, i18n("Internal error:\nFailed to open pipes for internal communication."));
     kapp->exit(1);
   }
   if (::pipe(fdPipeOut ) == -1 ) {
     perror( "Creating out pipe" );
-    KMessageBox::error(global->topLevel, i18n("Internal error:\nFailed to open pipes for internal communcation!"));
+    KMessageBox::error(global->topLevel, i18n("Internal error:\nFailed to open pipes for internal communication."));
     kapp->exit(1);
   }
 
   if (-1 == fcntl(fdPipeIn[0],F_SETFL,O_NONBLOCK)) {  // make socket non-blocking
     perror("fcntl()");
-    KMessageBox::error(global->topLevel, i18n("Internal error:\nFailed to open pipes for internal communcation!"));
+    KMessageBox::error(global->topLevel, i18n("Internal error:\nFailed to open pipes for internal communication."));
     kapp->exit(1);
   }
 
   if (-1 == fcntl(fdPipeOut[0],F_SETFL,O_NONBLOCK)) {  // make socket non-blocking
     perror("fcntl()");
-    KMessageBox::error(global->topLevel, i18n("Internal error:\nFailed to open pipes for internal communcation!"));
+    KMessageBox::error(global->topLevel, i18n("Internal error:\nFailed to open pipes for internal communication."));
     kapp->exit(1);
   }
-  
+
   notifier = new QSocketNotifier(fdPipeIn[0],QSocketNotifier::Read,this);
   connect(notifier,SIGNAL(activated(int)),this,SLOT(clientDone()));
 
@@ -1259,7 +1212,7 @@ DictInterface::DictInterface()
 
   client = new DictAsyncClient(fdPipeOut[0],fdPipeIn[1]);
   if (0!=pthread_create(&threadID,0,&(client->startThread),client)) {
-    KMessageBox::error(global->topLevel, i18n("Internal error:\nUnable to create thread!"));
+    KMessageBox::error(global->topLevel, i18n("Internal error:\nUnable to create thread."));
     kapp->exit(1);
   }
 
@@ -1276,7 +1229,7 @@ DictInterface::~DictInterface()
   if (0!=pthread_join(threadID,NULL))
     kdWarning() << "pthread_join failed!" << endl;
   delete client;
-  
+
   if ( ::close( fdPipeIn[0] ) == -1 ) {
     perror( "Closing fdPipeIn[0]" );
   }
@@ -1318,7 +1271,7 @@ void DictInterface::stop()
 }
 
 
-void DictInterface::define(QCString query)
+void DictInterface::define(const QString &query)
 {
   JobData *newJob = generateQuery(JobData::TDefine,query);
   if (newJob)
@@ -1326,10 +1279,10 @@ void DictInterface::define(QCString query)
 }
 
 
-void DictInterface::getDefinitions(QStrList* &query)
+void DictInterface::getDefinitions(QStringList query)
 {
   JobData *newjob = new JobData(JobData::TGetDefinitions,newServer,global->server,global->port,
-                                global->idleHold,global->timeout,global->pipeSize,global->authEnabled,
+                                global->idleHold,global->timeout,global->pipeSize, global->encoding,global->authEnabled,
                                 global->user,global->secret,global->headLayout);
   newjob->defines = query;
   newServer = false;
@@ -1337,7 +1290,7 @@ void DictInterface::getDefinitions(QStrList* &query)
 }
 
 
-void DictInterface::match(QCString query)
+void DictInterface::match(const QString &query)
 {
   JobData *newJob = generateQuery(JobData::TMatch,query);
 
@@ -1346,25 +1299,25 @@ void DictInterface::match(QCString query)
       newJob->strategy = ".";        // spell check strategy
     else
       newJob->strategy = global->strategies[global->currentStrategy].utf8();
-  
+
     insertJob(newJob);
   }
 }
 
 
 // fetch detailed db info
-void DictInterface::showDbInfo(QCString db)
+void DictInterface::showDbInfo(const QString &db)
 {
-  db = db.simplifyWhiteSpace();   // cleanup query string
-  if (db.isEmpty())
+  QString ndb = db.simplifyWhiteSpace();   // cleanup query string
+  if (ndb.isEmpty())
     return;
-  if (db.length()>100)               // shorten if necessary
-    db.truncate(100);
+  if (ndb.length()>100)               // shorten if necessary
+    ndb.truncate(100);
   JobData *newjob = new JobData(JobData::TShowDbInfo,newServer,global->server,global->port,
-                                global->idleHold,global->timeout,global->pipeSize,global->authEnabled,
+                                global->idleHold,global->timeout,global->pipeSize, global->encoding,global->authEnabled,
                                 global->user,global->secret,global->headLayout);
   newServer = false;
-  newjob->query = db.copy();            // construct job...
+  newjob->query = ndb;            // construct job...
   insertJob(newjob);
 }
 
@@ -1372,7 +1325,7 @@ void DictInterface::showDbInfo(QCString db)
 void DictInterface::showDatabases()
 {
   insertJob( new JobData(JobData::TShowDatabases,newServer,global->server,global->port,
-                         global->idleHold,global->timeout,global->pipeSize,global->authEnabled,
+                         global->idleHold,global->timeout,global->pipeSize, global->encoding,global->authEnabled,
                          global->user,global->secret,global->headLayout));
   newServer = false;
 }
@@ -1381,7 +1334,7 @@ void DictInterface::showDatabases()
 void DictInterface::showStrategies()
 {
   insertJob( new JobData(JobData::TShowStrategies,newServer,global->server,global->port,
-                         global->idleHold,global->timeout,global->pipeSize,global->authEnabled,
+                         global->idleHold,global->timeout,global->pipeSize, global->encoding,global->authEnabled,
                          global->user,global->secret,global->headLayout));
   newServer = false;
 }
@@ -1390,7 +1343,7 @@ void DictInterface::showStrategies()
 void DictInterface::showInfo()
 {
   insertJob( new JobData(JobData::TShowInfo,newServer,global->server,global->port,
-                         global->idleHold,global->timeout,global->pipeSize,global->authEnabled,
+                         global->idleHold,global->timeout,global->pipeSize, global->encoding,global->authEnabled,
                          global->user,global->secret,global->headLayout));
   newServer = false;
 }
@@ -1400,7 +1353,7 @@ void DictInterface::showInfo()
 void DictInterface::updateServer()
 {
   insertJob( new JobData(JobData::TUpdate,newServer,global->server,global->port,
-                         global->idleHold,global->timeout,global->pipeSize,global->authEnabled,
+                         global->idleHold,global->timeout,global->pipeSize, global->encoding,global->authEnabled,
                          global->user,global->secret,global->headLayout));
   newServer = false;
 }
@@ -1419,26 +1372,25 @@ void DictInterface::clientDone()
   }
 
   clientDoneInProgress = true;
-
+  QStringList::iterator it;
   JobData* job = jobList.getFirst();
   if (!job->canceled) {  // non-interupted job?
     if (JobData::ErrNoErr == job->error) {
       switch (job->type) {
       case JobData::TUpdate :
         global->serverDatabases.clear();
-        const char * s;
-        for ( QStrListIterator it(job->databases); (s=it.current()); ++it )
-          global->serverDatabases.append(QString::fromUtf8(s));
+        for (it = job->databases.begin(); it != job->databases.end(); ++it)
+          global->serverDatabases.append(*it);
         global->databases = global->serverDatabases;
         for (int i = global->databaseSets.count()-1;i>=0;i--)
           global->databases.prepend(global->databaseSets.at(i)->first());
-        global->databases.prepend(i18n("all databases"));
+        global->databases.prepend(i18n("All Databases"));
         global->currentDatabase = 0;
 
         global->strategies.clear();
-        for ( QStrListIterator it(job->strategies); (s=it.current()); ++it )
-          global->strategies.append(QString::fromUtf8(s));
-        global->strategies.prepend(i18n("spell check"));
+        for (it = job->strategies.begin(); it != job->strategies.end(); ++it)
+          global->strategies.append(*it);
+        global->strategies.prepend(i18n("Spell Check"));
         global->currentStrategy = 0;
         message = i18n(" Received database/strategy list ");
         emit stopped(message);
@@ -1502,7 +1454,7 @@ void DictInterface::clientDone()
         errMsg = i18n("A delay occurred which exceeded the\ncurrent timeout limit of %1 seconds.\nYou can modify this limit in the Preferences Dialog.").arg(global->timeout);
         break;
       case JobData::ErrBadHost:
-        errMsg = i18n("Unable to connect to:\n%1:%2\n\nCan't resolve hostname.").arg(job->server).arg(job->port);
+        errMsg = i18n("Unable to connect to:\n%1:%2\n\nCannot resolve hostname.").arg(job->server).arg(job->port);
         break;
       case JobData::ErrConnect:
         errMsg = i18n("Unable to connect to:\n%1:%2\n\n").arg(job->server).arg(job->port);
@@ -1515,7 +1467,7 @@ void DictInterface::clientDone()
         errMsg = i18n("The server is temporarily unavailable.");
         break;
       case JobData::ErrSyntax:
-        errMsg = i18n("The server reported a syntax error.\nThis shouldn't happen, please consider\nwriting a bug report.");
+        errMsg = i18n("The server reported a syntax error.\nThis shouldn't happen -- please consider\nwriting a bug report.");
         break;
       case JobData::ErrCommandNotImplemented:
         errMsg = i18n("A command that Kdict needs isn't\nimplemented on the server.");
@@ -1536,7 +1488,7 @@ void DictInterface::clientDone()
         errMsg = i18n("No strategies available.");
         break;
       case JobData::ErrServerError:
-        errMsg = i18n("The server sent an unexpected reply:\n\"%1\"\nThis shouldn't happen, please consider\nwriting a bug report").arg(QString::fromUtf8(job->result));
+        errMsg = i18n("The server sent an unexpected reply:\n\"%1\"\nThis shouldn't happen, please consider\nwriting a bug report").arg(job->result);
         break;
       case JobData::ErrMsgTooLong:
         errMsg = i18n("The server sent a response with a text line\nthat was too long.\n(RFC 2229: max. 1024 characters/6144 octets)");
@@ -1562,29 +1514,22 @@ void DictInterface::clientDone()
 }
 
 
-JobData* DictInterface::generateQuery(JobData::QueryType type,QCString query)
+JobData* DictInterface::generateQuery(JobData::QueryType type, QString query)
 {
   query = query.simplifyWhiteSpace();   // cleanup query string
   if (query.isEmpty())
     return 0L;
   if (query.length()>300)               // shorten if necessary
     query.truncate(300);
-  unsigned int i(0);
-  while (i < query.length()) {          // remove remaining illegal chars...
-    char c = query.data()[i];
-    if ((c=='\"')||(c=='\\'))
-      query.remove(i,1);
-    else
-      i++;
-  }
+  query = query.replace(QRegExp("[\"\\]"), "");  // remove remaining illegal chars...
   if (query.isEmpty())
     return 0L;
 
   JobData *newjob = new JobData(type,newServer,global->server,global->port,
-                                global->idleHold,global->timeout,global->pipeSize,global->authEnabled,
+                                global->idleHold,global->timeout,global->pipeSize, global->encoding, global->authEnabled,
                                 global->user,global->secret,global->headLayout);
   newServer = false;
-  newjob->query = query.copy();            // construct job...
+  newjob->query = query;            // construct job...
 
   if (global->currentDatabase == 0)     // all databases
     newjob->databases.append("*");
@@ -1603,7 +1548,7 @@ JobData* DictInterface::generateQuery(JobData::QueryType type,QCString query)
       newjob->databases.append(global->databases[global->currentDatabase].utf8().data());
     }
   }
-    
+
   return newjob;
 }
 
@@ -1628,12 +1573,12 @@ void DictInterface::startClient()
     kdDebug(5004) << "This shouldnt happen, startClient called, but clientList is empty" << endl;
     return;
   }
-  
+
   client->insertJob(jobList.getFirst());
   char buf;                           // write one char in the pipe to the async thread
   if (::write(fdPipeOut[1],&buf,1) == -1)
     ::perror( "startClient()" );
-  
+
   QString message;
   switch (jobList.getFirst()->type) {
    case JobData::TDefine:
@@ -1665,7 +1610,7 @@ void DictInterface::cleanPipes()
   tv.tv_sec = 0;
   tv.tv_usec = 0;
 
-  do {               
+  do {
     FD_ZERO(&rfds);
     FD_SET(fdPipeIn[0],&rfds);
     if (1==(ret=select(FD_SETSIZE,&rfds,NULL,NULL,&tv)))
