@@ -2,7 +2,7 @@
 *                               dlgSystem.cpp
 *                             -------------------
 *
-*    Revision     : $Id: dlgSystem.cpp,v 1.21 2004/07/04 18:38:27 binner Exp $
+*    Revision     : $Id: dlgSystem.cpp 390406 2005-02-17 22:24:27Z fberger $
 *    begin        : Tue Jan 29 2002
 *    copyright    : (C) 2002 by Patrick Charbonnier
 *                 : Based On Caitoo v.0.7.3 (c) 1998 - 2000, Matej Koss
@@ -45,10 +45,15 @@
 #include "kmainwidget.h"
 #include "dlgSystem.h"
 
+#include <qbuttongroup.h>
+#include <qlabel.h>
+
 
 DlgSystem::DlgSystem(QWidget * parent)
     : DlgSystemBase(parent)
 {
+    bg_window->hide();
+    textLabel4->hide();
 }
 
 
