@@ -148,23 +148,34 @@ GaduSession::disableNotifiers()
 	}
 }
 
+void
+GaduSession::dccRequest( const unsigned int uin )
+{
+	if ( session_ ) {
+		gg_dcc_request( session_, uin );
+	}
+}
+
 void
 GaduSession::login( KGaduLoginParams* loginp )
 {
+	QCString desc = textcodec->fromUnicode( loginp->statusDescr );
+
 	memset( &params_, 0, sizeof(params_) );
 
+	params_.status_descr	= (char*)desc.data();
+
 	params_.uin		= loginp->uin;
 	params_.password	= (char *)( loginp->password.ascii() );
-	params_.status		= loginp->status | ( loginp->forFriends ? GG_STATUS_FRIENDS_MASK : 0);
-	params_.status_descr	= ( textcodec->fromUnicode( loginp->statusDescr ).data() );
+	params_.status		= loginp->status | ( loginp->forFriends ? GG_STATUS_FRIENDS_MASK : 0 );
 	params_.async		= 1;
 	params_.tls		= loginp->useTls;
 	params_ .server_addr	= loginp->server;
 	params_.client_addr	= loginp->client_addr;
 	params_.client_port	= loginp->client_port;
 
-	kdDebug(14100) << "LOGIN IP: " << loginp->client_addr << " loginp->uin" << endl;
-	
+	kdDebug(14100) << "LOGIN IP: " << loginp->client_addr << endl;
+
 	if ( loginp->useTls ) {
 		params_.server_port = GG_HTTPS_PORT;
 	}
@@ -176,6 +187,7 @@ GaduSession::login( KGaduLoginParams* loginp )
 
 	kdDebug(14100)<<"gadusession::login, server ( " << loginp->server << " ), tls(" << loginp->useTls << ") " <<endl;
 	login( &params_ );
+
 }
 
 void
@@ -189,7 +201,7 @@ GaduSession::destroySession()
 }
 
 void
-GaduSession::logoff( KopeteAccount::DisconnectReason reason )
+GaduSession::logoff( Kopete::Account::DisconnectReason reason )
 {
 	destroySession();
 	emit disconnect( reason );
@@ -234,7 +246,7 @@ GaduSession::removeNotify( uin_t uin )
 }
 
 int
-GaduSession::sendMessage( uin_t recipient, const KopeteMessage& msg, int msgClass )
+GaduSession::sendMessage( uin_t recipient, const Kopete::Message& msg, int msgClass )
 {
 	QString sendMsg;
 	QCString cpMsg;
@@ -606,14 +618,14 @@ GaduSession::checkDescriptor()
 	disableNotifiers();
 
 	struct gg_event* event;
-	struct gg_dcc*   dccSock;
+//	struct gg_dcc*   dccSock;
 	KGaduMessage	gaduMessage;
 	KGaduNotify	gaduNotify;
 
 	if ( !( event = gg_watch_fd( session_ ) ) ) {
 		kdDebug(14100)<<"Connection was broken for some reason"<<endl;
 		destroyNotifiers();
-		logoff( KopeteAccount::ConnectionReset );
+		logoff( Kopete::Account::ConnectionReset );
 		return;
 	}
 
@@ -626,20 +638,19 @@ GaduSession::checkDescriptor()
 
 	switch( event->type ) {
 		case GG_EVENT_MSG:
-			if ( event->event.msg.msgclass == GG_CLASS_CTCP ) {
+			kdDebug(14100) << "incoming message:class:" << event->event.msg.msgclass << endl;
+			if ( event->event.msg.msgclass & GG_CLASS_CTCP ) {
 				kdDebug( 14100 ) << "incomming ctcp " << endl;
 				// TODO: DCC CONNECTION
 				emit incomingCtcp( event->event.msg.sender );
-				break;
 			}
-			if ( event->event.msg.msgclass == GG_CLASS_MSG ||  event->event.msg.msgclass == GG_CLASS_CHAT ) {
+			if ( event->event.msg.msgclass & GG_CLASS_MSG || event->event.msg.msgclass & GG_CLASS_CHAT ) {
 				gaduMessage.message =
 					textcodec->toUnicode((const char*)event->event.msg.message);
 				gaduMessage.sender_id = event->event.msg.sender;
 				gaduMessage.sendTime.setTime_t( event->event.msg.time, Qt::LocalTime );
 				gaduMessage.message = rtf->convertToHtml( gaduMessage.message, event->event.msg.formats_length, event->event.msg.formats );
 				emit messageReceived( &gaduMessage );
-				break;
 			}
 		break;
 		case GG_EVENT_ACK:
@@ -701,7 +712,7 @@ GaduSession::checkDescriptor()
 		case GG_EVENT_DISCONNECT:
 			kdDebug(14100)<<"event Disconnected"<<endl;
 			// it should be called either when we requested disconnect, or when other client connects with our UID
-			logoff( KopeteAccount::Manual );
+			logoff( Kopete::Account::Manual );
 		break;
 		case GG_EVENT_PONG:
 			emit pong();
