@@ -1,4 +1,4 @@
-/* $Id: common.c,v 1.5 2004/12/07 12:09:31 gj Exp $ */
+/* $Id: common.c 436359 2005-07-19 15:34:38Z gj $ */
 
 /*
  *  (C) Copyright 2001-2002 Wojtek Kaniewski <wojtekka@irc.pl>
@@ -13,10 +13,10 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- *  02111-1307, USA.
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307,
+ *  USA.
  */
 
 #include <sys/types.h>
@@ -39,7 +39,7 @@
 
 #include "libgadu.h"
 
-FILE *gg_debug_file;
+FILE *gg_debug_file = NULL;
 
 #ifndef GG_DEBUG_DISABLE
 
@@ -55,7 +55,7 @@ void gg_debug(int level, const char *format, ...)
 {
 	va_list ap;
 	int old_errno = errno;
-
+	
 	if (gg_debug_handler) {
 		va_start(ap, format);
 		(*gg_debug_handler)(level, format, ap);
@@ -63,7 +63,7 @@ void gg_debug(int level, const char *format, ...)
 
 		goto cleanup;
 	}
-
+	
 	if ((gg_debug_level & level)) {
 		va_start(ap, format);
 		vfprintf((gg_debug_file) ? gg_debug_file : stderr, format, ap);
@@ -91,10 +91,10 @@ cleanup:
  */
 char *gg_vsaprintf(const char *format, va_list ap)
 {
-        int size = 0;
+	int size = 0;
 	const char *start;
 	char *buf = NULL;
-
+	
 #ifdef __GG_LIBGADU_HAVE_VA_COPY
 	va_list aq;
 
@@ -107,13 +107,13 @@ char *gg_vsaprintf(const char *format, va_list ap)
 #  endif
 #endif
 
-	start = format;
+	start = format; 
 
 #ifndef __GG_LIBGADU_HAVE_C99_VSNPRINTF
 	{
 		int res;
 		char *tmp;
-
+		
 		size = 128;
 		do {
 			size *= 2;
@@ -128,7 +128,7 @@ char *gg_vsaprintf(const char *format, va_list ap)
 #else
 	{
 		char tmp[2];
-
+		
 		/* libce Solarisa przy buforze NULL zawsze zwracaj -1, wic
 		 * musimy poda co istniejcego jako cel printf()owania. */
 		size = vsnprintf(tmp, sizeof(tmp), format, ap);
@@ -138,7 +138,7 @@ char *gg_vsaprintf(const char *format, va_list ap)
 #endif
 
 	format = start;
-
+	
 #ifdef __GG_LIBGADU_HAVE_VA_COPY
 	vsnprintf(buf, size + 1, format, aq);
 	va_end(aq);
@@ -150,7 +150,7 @@ char *gg_vsaprintf(const char *format, va_list ap)
 	vsnprintf(buf, size + 1, format, ap);
 #  endif
 #endif
-
+	
 	return buf;
 }
 
@@ -180,36 +180,36 @@ char *gg_saprintf(const char *format, ...)
 
 /*
  * gg_get_line() // funkcja pomocnicza
- *
+ * 
  * podaje kolejn lini z bufora tekstowego. niszczy go bezpowrotnie, dzielc
  * na kolejne stringi. zdarza si, nie ma potrzeby pisania funkcji dublujcej
  * bufor eby tylko mie nieruszone dane wejciowe, skoro i tak nie bd nam
  * poniej potrzebne. obcina `\r\n'.
- *
+ * 
  *  - ptr - wskanik do zmiennej, ktra przechowuje aktualn pozycj
  *    w przemiatanym buforze
- *
+ * 
  * wskanik do kolejnej linii tekstu lub NULL, jeli to ju koniec bufora.
  */
 char *gg_get_line(char **ptr)
 {
-        char *foo, *res;
+	char *foo, *res;
 
-        if (!ptr || !*ptr || !strcmp(*ptr, ""))
-                return NULL;
+	if (!ptr || !*ptr || !strcmp(*ptr, ""))
+		return NULL;
 
-        res = *ptr;
+	res = *ptr;
 
-        if (!(foo = strchr(*ptr, '\n')))
-                *ptr += strlen(*ptr);
-        else {
-                *ptr = foo + 1;
-                *foo = 0;
-                if (strlen(res) > 1 && res[strlen(res) - 1] == '\r')
-                        res[strlen(res) - 1] = 0;
-        }
+	if (!(foo = strchr(*ptr, '\n')))
+		*ptr += strlen(*ptr);
+	else {
+		*ptr = foo + 1;
+		*foo = 0;
+		if (strlen(res) > 1 && res[strlen(res) - 1] == '\r')
+			res[strlen(res) - 1] = 0;
+	}
 
-        return res;
+	return res;
 }
 
 /*
@@ -227,27 +227,27 @@ char *gg_get_line(char **ptr)
  */
 int gg_connect(void *addr, int port, int async)
 {
-	int sock, one = 1;
+	int sock, one = 1, errno2;
 	struct sockaddr_in sin;
 	struct in_addr *a = addr;
-        struct sockaddr_in myaddr;
+	struct sockaddr_in myaddr;
 
 	gg_debug(GG_DEBUG_FUNCTION, "** gg_connect(%s, %d, %d);\n", inet_ntoa(*a), port, async);
-
+	
 	if ((sock = socket(AF_INET, SOCK_STREAM, IPPROTO_TCP)) == -1) {
 		gg_debug(GG_DEBUG_MISC, "// gg_connect() socket() failed (errno=%d, %s)\n", errno, strerror(errno));
 		return -1;
 	}
 
-        memset(&myaddr, 0, sizeof(myaddr));
-        myaddr.sin_family = AF_INET;
+	memset(&myaddr, 0, sizeof(myaddr));
+	myaddr.sin_family = AF_INET;
 
-        myaddr.sin_addr.s_addr = gg_local_ip;
+	myaddr.sin_addr.s_addr = gg_local_ip;
 
-        if(bind(sock, (struct sockaddr *) &myaddr, sizeof(myaddr)) == -1) {
-                gg_debug(GG_DEBUG_MISC, "// gg_connect() bind() failed (errno=%d, %s)\n", errno, strerror(errno));
-                return -1;
-        }
+	if (bind(sock, (struct sockaddr *) &myaddr, sizeof(myaddr)) == -1) {
+		gg_debug(GG_DEBUG_MISC, "// gg_connect() bind() failed (errno=%d, %s)\n", errno, strerror(errno));
+		return -1;
+	}
 
 #ifdef ASSIGN_SOCKETS_TO_THREADS
 	gg_win32_thread_socket(0, sock);
@@ -260,7 +260,9 @@ int gg_connect(void *addr, int port, int async)
 		if (fcntl(sock, F_SETFL, O_NONBLOCK) == -1) {
 #endif
 			gg_debug(GG_DEBUG_MISC, "// gg_connect() ioctl() failed (errno=%d, %s)\n", errno, strerror(errno));
+			errno2 = errno;
 			close(sock);
+			errno = errno2;
 			return -1;
 		}
 	}
@@ -268,16 +270,18 @@ int gg_connect(void *addr, int port, int async)
 	sin.sin_port = htons(port);
 	sin.sin_family = AF_INET;
 	sin.sin_addr.s_addr = a->s_addr;
-
+	
 	if (connect(sock, (struct sockaddr*) &sin, sizeof(sin)) == -1) {
 		if (errno && (!async || errno != EINPROGRESS)) {
 			gg_debug(GG_DEBUG_MISC, "// gg_connect() connect() failed (errno=%d, %s)\n", errno, strerror(errno));
+			errno2 = errno;
 			close(sock);
+			errno = errno2;
 			return -1;
 		}
 		gg_debug(GG_DEBUG_MISC, "// gg_connect() connect() in progress\n");
 	}
-
+	
 	return sock;
 }
 
@@ -290,12 +294,16 @@ int gg_connect(void *addr, int port, int async)
  *  - buf - wskanik do bufora
  *  - length - dugo bufora
  *
- * jeli trafi na bd odczytu, zwraca NULL. inaczej zwraca buf.
+ * jeli trafi na bd odczytu lub podano nieprawidowe parametry, zwraca NULL.
+ * inaczej zwraca buf.
  */
 char *gg_read_line(int sock, char *buf, int length)
 {
 	int ret;
 
+	if (!buf || length < 0)
+		return NULL;
+
 	for (; length > 1; buf++, length--) {
 		do {
 			if ((ret = read(sock, buf, 1)) == -1 && errno != EINTR) {
@@ -328,13 +336,17 @@ char *gg_read_line(int sock, char *buf, int length)
  */
 void gg_chomp(char *line)
 {
-	if (!line || strlen(line) < 1)
+	int len;
+	
+	if (!line)
 		return;
 
-	if (line[strlen(line) - 1] == '\n')
-		line[strlen(line) - 1] = 0;
-	if (line[strlen(line) - 1] == '\r')
-		line[strlen(line) - 1] = 0;
+	len = strlen(line);
+	
+	if (len > 0 && line[len - 1] == '\n')
+		line[--len] = 0;
+	if (len > 0 && line[len - 1] == '\r')
+		line[--len] = 0;
 }
 
 /*
@@ -352,10 +364,10 @@ char *gg_urlencode(const char *str)
 {
 	char *q, *buf, hex[] = "0123456789abcdef";
 	const char *p;
-	int size = 0;
+	unsigned int size = 0;
 
-	if (!str && !(str = strdup("")))
-		return NULL;
+	if (!str)
+		str = "";
 
 	for (p = str; *p; p++, size++) {
 		if (!((*p >= 'a' && *p <= 'z') || (*p >= 'A' && *p <= 'Z') || (*p >= '0' && *p <= '9') || *p == ' ') || (*p == '@') || (*p == '.') || (*p == '-'))
@@ -404,18 +416,18 @@ int gg_http_hash(const char *format, ...)
 	va_start(ap, format);
 
 	for (j = 0; j < strlen(format); j++) {
-		unsigned char *arg, buf[16];
+		char *arg, buf[16];
 
 		if (format[j] == 'u') {
 			snprintf(buf, sizeof(buf), "%d", va_arg(ap, uin_t));
 			arg = buf;
 		} else {
-			if (!(arg = va_arg(ap, unsigned char*)))
+			if (!(arg = va_arg(ap, char*)))
 				arg = "";
-		}
+		}	
 
 		i = 0;
-		while ((c = (int) arg[i++]) != 0) {
+		while ((c = (unsigned char) arg[i++]) != 0) {
 			a = (c ^ b) + (c << 8);
 			b = (a >> 24) | (a << 8);
 		}
@@ -446,12 +458,12 @@ struct in_addr *gg_gethostbyname(const char *hostname)
 	int h_errnop, ret;
 	size_t buflen = 1024;
 	int new_errno;
-
+	
 	new_errno = ENOMEM;
-
+	
 	if (!(addr = malloc(sizeof(struct in_addr))))
 		goto cleanup;
-
+	
 	if (!(hp = calloc(1, sizeof(*hp))))
 		goto cleanup;
 
@@ -459,45 +471,44 @@ struct in_addr *gg_gethostbyname(const char *hostname)
 		goto cleanup;
 
 	tmpbuf = buf;
-
+	
 	while ((ret = gethostbyname_r(hostname, hp, buf, buflen, &hp2, &h_errnop)) == ERANGE) {
 		buflen *= 2;
-
+		
 		if (!(tmpbuf = realloc(buf, buflen)))
 			break;
-
+		
 		buf = tmpbuf;
 	}
-
+	
 	if (ret)
 		new_errno = h_errnop;
 
 	if (ret || !hp2 || !tmpbuf)
 		goto cleanup;
-
+	
 	memcpy(addr, hp->h_addr, sizeof(struct in_addr));
-
+	
 	free(buf);
 	free(hp);
-
+	
 	return addr;
-
+	
 cleanup:
 	errno = new_errno;
-
+	
 	if (addr)
 		free(addr);
 	if (hp)
 		free(hp);
 	if (buf)
 		free(buf);
-
+	
 	return NULL;
 #else
 	struct hostent *hp;
 
 	if (!(addr = malloc(sizeof(struct in_addr)))) {
-		errno = ENOMEM;
 		goto cleanup;
 	}
 
@@ -507,7 +518,7 @@ cleanup:
 	memcpy(addr, hp->h_addr, sizeof(struct in_addr));
 
 	return addr;
-
+	
 cleanup:
 	if (addr)
 		free(addr);
@@ -535,7 +546,7 @@ struct gg_win32_thread *gg_win32_threads = 0;
  * jeli na win32 przy poczeniach synchronicznych zapamitamy w jakim
  * wtku uruchomilimy funkcj, ktra si z czymkolwiek czy, to z osobnego
  * wtku moemy anulowa poczenie poprzez gg_win32_thread_socket(watek, -1);
- *
+ * 
  * - thread_id - id wtku. jeli jest rwne 0, brany jest aktualny wtek,
  *               jeli rwne -1, usuwa wpis o podanym sockecie.
  * - socket - deskryptor gniazda. jeli rwne 0, zwraca deskryptor gniazda
@@ -552,42 +563,41 @@ int gg_win32_thread_socket(int thread_id, int socket)
 
 	if (!thread_id)
 		thread_id = GetCurrentThreadId();
-
+	
 	while (wsk) {
 		if ((thread_id == -1 && wsk->socket == socket) || wsk->id == thread_id) {
 			if (close) {
 				/* socket zostaje usuniety */
-                        	closesocket(wsk->socket);
-         			*p_wsk = wsk->next;
-         			free(wsk);
-         			return 1;
-                        } else if (!socket) {
+				closesocket(wsk->socket);
+				*p_wsk = wsk->next;
+				free(wsk);
+				return 1;
+			} else if (!socket) {
 				/* socket zostaje zwrocony */
 				return wsk->socket;
-                        } else {
+			} else {
 				/* socket zostaje ustawiony */
 				wsk->socket = socket;
 				return socket;
 			}
-               }
+		}
+		p_wsk = &(wsk->next);
+		wsk = wsk->next;
+	}
 
-               p_wsk = &(wsk->next);
-               wsk = wsk->next;
-        }
-
-        if (close && socket != -1)
+	if (close && socket != -1)
 		closesocket(socket);
-        if (close || !socket)
+	if (close || !socket)
 		return 0;
+	
+	/* Dodaje nowy element */
+	wsk = malloc(sizeof(gg_win32_thread));
+	wsk->id = thread_id;
+	wsk->socket = socket;
+	wsk->next = 0;
+	*p_wsk = wsk;
 
-        /* Dodaje nowy element */
-        wsk = malloc(sizeof(gg_win32_thread));
-        wsk->id = thread_id;
-        wsk->socket = socket;
-        wsk->next = 0;
-        *p_wsk = wsk;
-
-        return socket;
+	return socket;
 }
 
 #endif /* ASSIGN_SOCKETS_TO_THREADS */
@@ -607,14 +617,14 @@ static char gg_base64_charset[] =
 char *gg_base64_encode(const char *buf)
 {
 	char *out, *res;
-	int i = 0, j = 0, k = 0, len = strlen(buf);
-
+	unsigned int i = 0, j = 0, k = 0, len = strlen(buf);
+	
 	res = out = malloc((len / 3 + 1) * 4 + 2);
 
 	if (!res)
 		return NULL;
-
-	while (j < len) {
+	
+	while (j <= len) {
 		switch (i % 4) {
 			case 0:
 				k = (buf[j] & 252) >> 2;
@@ -646,9 +656,9 @@ char *gg_base64_encode(const char *buf)
 	if (i % 4)
 		for (j = 0; j < 4 - (i % 4); j++, out++)
 			*out = '=';
-
+	
 	*out = 0;
-
+	
 	return res;
 }
 
@@ -665,11 +675,11 @@ char *gg_base64_decode(const char *buf)
 {
 	char *res, *save, *foo, val;
 	const char *end;
-	int index = 0;
+	unsigned int index = 0;
 
 	if (!buf)
 		return NULL;
-
+	
 	save = res = calloc(1, (strlen(buf) / 4 + 1) * 3 + 2);
 
 	if (!save)
@@ -706,7 +716,7 @@ char *gg_base64_decode(const char *buf)
 		index %= 4;
 	}
 	*res = 0;
-
+	
 	return save;
 }
 
@@ -714,7 +724,7 @@ char *gg_base64_decode(const char *buf)
  * gg_proxy_auth() // funkcja wewntrzna
  *
  * tworzy nagwek autoryzacji dla proxy.
- *
+ * 
  * zaalokowany tekst lub NULL, jeli proxy nie jest wczone lub nie wymaga
  * autoryzacji.
  */
@@ -722,7 +732,7 @@ char *gg_proxy_auth()
 {
 	char *tmp, *enc, *out;
 	unsigned int tmp_size;
-
+	
 	if (!gg_proxy_enabled || !gg_proxy_username || !gg_proxy_password)
 		return NULL;
 
@@ -735,14 +745,14 @@ char *gg_proxy_auth()
 		free(tmp);
 		return NULL;
 	}
-
+	
 	free(tmp);
 
 	if (!(out = malloc(strlen(enc) + 40))) {
 		free(enc);
 		return NULL;
 	}
-
+	
 	snprintf(out, strlen(enc) + 40,  "Proxy-Authorization: Basic %s\r\n", enc);
 
 	free(enc);
@@ -759,7 +769,7 @@ static int gg_crc32_initialized = 0;
 static void gg_crc32_make_table()
 {
 	uint32_t h = 1;
-	int i, j;
+	unsigned int i, j;
 
 	memset(gg_crc32_table, 0, sizeof(gg_crc32_table));
 
@@ -789,6 +799,9 @@ uint32_t gg_crc32(uint32_t crc, const unsigned char *buf, int len)
 	if (!gg_crc32_initialized)
 		gg_crc32_make_table();
 
+	if (!buf || len < 0)
+		return crc;
+
 	crc ^= 0xffffffffL;
 
 	while (len--)
