@@ -1,4 +1,4 @@
-/* $Id: libgadu.h,v 1.7 2004/12/23 21:22:04 gj Exp $ */
+/* $Id: libgadu.h 437088 2005-07-20 22:20:52Z mueller $ */
 
 /*
  *  (C) Copyright 2001-2003 Wojtek Kaniewski <wojtekka@irc.pl>
@@ -33,15 +33,15 @@
 extern "C" {
 #endif
 
+#ifdef HAVE_STDINT_H
+#include <stdint.h>
+#endif
+	
 #include <libgadu-config.h>
 #include <sys/types.h>
 #include <stdio.h>
 #include <stdarg.h>
 
-#ifdef HAVE_STDINT_H
-#include <stdint.h>
-#endif
-	
 #ifdef __GG_LIBGADU_HAVE_OPENSSL
 #include <openssl/ssl.h>
 #endif
@@ -57,10 +57,10 @@ typedef uint32_t uin_t;
  * oglna struktura opisujca rne sesje. przydatna w klientach.
  */
 #define gg_common_head(x) \
-        int fd;                 /* podgldany deskryptor */ \
-        int check;              /* sprawdzamy zapis czy odczyt */ \
-        int state;              /* aktualny stan maszynki */ \
-        int error;              /* kod bdu dla GG_STATE_ERROR */ \
+	int fd;			/* podgldany deskryptor */ \
+	int check;		/* sprawdzamy zapis czy odczyt */ \
+	int state;		/* aktualny stan maszynki */ \
+	int error;		/* kod bdu dla GG_STATE_ERROR */ \
 	int type;		/* rodzaj sesji */ \
 	int id;			/* identyfikator */ \
 	int timeout;		/* sugerowany timeout w sekundach */ \
@@ -111,7 +111,7 @@ struct gg_session {
 
 	char *recv_buf;		/* bufor na otrzymywane pakiety */
 	int recv_done;		/* ile ju wczytano do bufora */
-        int recv_left;		/* i ile jeszcze trzeba wczyta */
+	int recv_left;		/* i ile jeszcze trzeba wczyta */
 
 	int protocol_version;	/* wersja uywanego protokou */
 	char *client_version;	/* wersja uywanego klienta */
@@ -150,17 +150,17 @@ struct gg_session {
 struct gg_http {
 	gg_common_head(struct gg_http)
 
-        int async;              /* czy poczenie asynchroniczne */
+	int async;              /* czy poczenie asynchroniczne */
 	int pid;                /* pid procesu resolvera */
 	int port;               /* port, z ktrym si czymy */
 
-        char *query;            /* bufor zapytania http */
-        char *header;           /* bufor nagwka */
-        int header_size;        /* rozmiar wczytanego nagwka */
-        char *body;             /* bufor otrzymanych informacji */
-        unsigned int body_size; /* oczekiwana ilo informacji */
+	char *query;            /* bufor zapytania http */
+	char *header;           /* bufor nagwka */
+	int header_size;        /* rozmiar wczytanego nagwka */
+	char *body;             /* bufor otrzymanych informacji */
+	unsigned int body_size; /* oczekiwana ilo informacji */
 
-        void *data;             /* dane danej operacji http */
+	void *data;             /* dane danej operacji http */
 
 	char *user_data;	/* dane uytkownika, nie s zwalniane przez gg_http_free() */
 
@@ -265,27 +265,27 @@ enum gg_session_t {
  * opisuje stan asynchronicznej maszyny.
  */
 enum gg_state_t {
-        /* wsplne */
-        GG_STATE_IDLE = 0,		/* nie powinno wystpi. */
-        GG_STATE_RESOLVING,             /* wywoa gethostbyname() */
+		/* wsplne */
+	GG_STATE_IDLE = 0,		/* nie powinno wystpi. */
+	GG_STATE_RESOLVING,             /* wywoa gethostbyname() */
 	GG_STATE_CONNECTING,            /* wywoa connect() */
 	GG_STATE_READING_DATA,		/* czeka na dane http */
 	GG_STATE_ERROR,			/* wystpi bd. kod w x->error */
 
-        /* gg_session */
+		/* gg_session */
 	GG_STATE_CONNECTING_HUB,	/* wywoa connect() na huba */
 	GG_STATE_CONNECTING_GG,         /* wywoa connect() na serwer */
 	GG_STATE_READING_KEY,           /* czeka na klucz */
 	GG_STATE_READING_REPLY,         /* czeka na odpowied */
 	GG_STATE_CONNECTED,             /* poczy si */
 
-        /* gg_http */
+		/* gg_http */
 	GG_STATE_SENDING_QUERY,		/* wysya zapytanie http */
 	GG_STATE_READING_HEADER,	/* czeka na nagwek http */
 	GG_STATE_PARSING,               /* przetwarza dane */
 	GG_STATE_DONE,                  /* skoczy */
 
-	/* gg_dcc */
+		/* gg_dcc */
 	GG_STATE_LISTENING,		/* czeka na poczenia */
 	GG_STATE_READING_UIN_1,		/* czeka na uin peera */
 	GG_STATE_READING_UIN_2,		/* czeka na swj uin */
@@ -350,8 +350,9 @@ struct gg_login_params {
 	uint16_t external_port;		/* port widziany na zewnatrz */
 	int tls;			/* czy czymy po TLS? */
 	int image_size;			/* maksymalny rozmiar obrazka w KiB */
+	int era_omnix;			/* czy udawa klienta era omnix? */
 
-	char dummy[7 * sizeof(int)];	/* miejsce na kolejnych 8 zmiennych,
+	char dummy[6 * sizeof(int)];	/* miejsce na kolejnych 6 zmiennych,
 					 * eby z dodaniem parametru nie 
 					 * zmienia si rozmiar struktury */
 };
@@ -500,8 +501,8 @@ typedef struct gg_pubdir50_s *gg_pubdir50_t;
  */
 struct gg_event {
 	int type;	/* rodzaj zdarzenia -- gg_event_t */
-        union {		/* @event */
-                struct gg_notify_reply *notify;	/* informacje o licie kontaktw -- GG_EVENT_NOTIFY */
+	union {		/* @event */
+		struct gg_notify_reply *notify;	/* informacje o licie kontaktw -- GG_EVENT_NOTIFY */
 
 		enum gg_failure_t failure;	/* bd poczenia -- GG_EVENT_FAILURE */
 
@@ -522,20 +523,20 @@ struct gg_event {
 			
 			int formats_length;	/* dugo informacji o formatowaniu tekstu */
 			void *formats;		/* informacje o formatowaniu tekstu */
-                } msg;
+		} msg;
 		
 		struct {			/* @notify_descr informacje o licie kontaktw z opisami stanu -- GG_EVENT_NOTIFY_DESCR */
 			struct gg_notify_reply *notify;	/* informacje o licie kontaktw */
 			char *descr;		/* opis stanu */
 		} notify_descr;
 		
-                struct {			/* @status zmiana stanu -- GG_EVENT_STATUS */
+		struct {			/* @status zmiana stanu -- GG_EVENT_STATUS */
 			uin_t uin;		/* numer */
 			uint32_t status;	/* nowy stan */
 			char *descr;		/* opis stanu */
 		} status;
 
-                struct {			/* @status60 zmiana stanu -- GG_EVENT_STATUS60 */
+		struct {			/* @status60 zmiana stanu -- GG_EVENT_STATUS60 */
 			uin_t uin;		/* numer */
 			int status;	/* nowy stan */
 			uint32_t remote_ip;	/* adres ip */
@@ -748,6 +749,7 @@ struct gg_http *gg_unregister3(uin_t uin, const char *password, const char *toke
 /* przypomnienie hasa e-mailem */
 struct gg_http *gg_remind_passwd(uin_t uin, int async);
 struct gg_http *gg_remind_passwd2(uin_t uin, const char *tokenid, const char *tokenval, int async);
+struct gg_http *gg_remind_passwd3(uin_t uin, const char *email, const char *tokenid, const char *tokenval, int async);
 #define gg_remind_passwd_watch_fd gg_pubdir_watch_fd
 #define gg_remind_passwd_free gg_pubdir_free
 #define gg_free_remind_passwd gg_pubdir_free
@@ -813,6 +815,7 @@ struct gg_dcc *gg_dcc_get_file(uint32_t ip, uint16_t port, uin_t my_uin, uin_t p
 struct gg_dcc *gg_dcc_voice_chat(uint32_t ip, uint16_t port, uin_t my_uin, uin_t peer_uin);
 void gg_dcc_set_type(struct gg_dcc *d, int type);
 int gg_dcc_fill_file_info(struct gg_dcc *d, const char *filename);
+int gg_dcc_fill_file_info2(struct gg_dcc *d, const char *filename, const char *local_filename);
 int gg_dcc_voice_send(struct gg_dcc *d, char *buf, int length);
 
 #define GG_DCC_VOICE_FRAME_LENGTH 195
@@ -940,11 +943,12 @@ int gg_image_queue_remove(struct gg_session *s, struct gg_image_queue *q, int fr
 #define GG_HTTPS_PORT 443
 #define GG_HTTP_USERAGENT "Mozilla/4.7 [en] (Win98; I)"
 
-#define GG_DEFAULT_CLIENT_VERSION "6, 0, 0, 132"
-#define GG_DEFAULT_PROTOCOL_VERSION 0x20
+#define GG_DEFAULT_CLIENT_VERSION "6, 1, 0, 158"
+#define GG_DEFAULT_PROTOCOL_VERSION 0x24
 #define GG_DEFAULT_TIMEOUT 30
 #define GG_HAS_AUDIO_MASK 0x40000000
-#define GG_LIBGADU_VERSION "20041222"
+#define GG_ERA_OMNIX_MASK 0x04000000
+#define GG_LIBGADU_VERSION "CVS"
 
 #define GG_DEFAULT_DCC_PORT 1550
 
