@@ -15,7 +15,19 @@
     *************************************************************************
 */
 
-#include <qtimer.h>
+#include "irccontactmanager.h"
+#include "ircchannelcontact.h"
+#include "ircusercontact.h"
+#include "ircservercontact.h"
+#include "ircaccount.h"
+#include "ircprotocol.h"
+
+#include "kopeteview.h"
+#include "kopeteuiglobal.h"
+#include "kcodecaction.h"
+#include "kopetemetacontact.h"
+#include "kopetestdaction.h"
+#include "kopetemessagemanagerfactory.h"
 
 #include <kdebug.h>
 #include <krun.h>
@@ -25,31 +37,26 @@
 #include <kglobal.h>
 #include <kmessagebox.h>
 
-#include "kopeteview.h"
-#include "kopeteuiglobal.h"
-#include "kcodecaction.h"
-#include "kopetemetacontact.h"
-#include "kopetestdaction.h"
-#include "kopetemessagemanagerfactory.h"
+#include <qtimer.h>
 
-#include "irccontactmanager.h"
-#include "ircchannelcontact.h"
-#include "ircusercontact.h"
-#include "ircservercontact.h"
-#include "ircaccount.h"
-#include "ircprotocol.h"
+//This is the number of nicknames we will process concurrently when joining a channel
+//Lower numbers ensure less GUI blocking, but take marginally longer to complete.
+//Higher numbers are absolute fastest, but block GUI until all members are added
+#define NICK_BATCH_LENGTH 1
 
-IRCChannelContact::IRCChannelContact(IRCContactManager *contactManager, const QString &channel, KopeteMetaContact *metac)
+IRCChannelContact::IRCChannelContact(IRCContactManager *contactManager, const QString &channel, Kopete::MetaContact *metac)
 	: IRCContact(contactManager, channel, metac, "irc_channel")
 {
+	KIRC::Engine *engine = kircEngine();
+
 	mInfoTimer = new QTimer( this );
 	QObject::connect(mInfoTimer, SIGNAL(timeout()), this, SLOT( slotUpdateInfo() ) );
 
-	QObject::connect( MYACCOUNT->engine(), SIGNAL(incomingUserIsAway( const QString &, const QString & )),
+	QObject::connect(engine, SIGNAL(incomingUserIsAway(const QString &, const QString &)),
 		this, SLOT(slotIncomingUserIsAway(const QString &, const QString &)));
 
-	QObject::connect( MYACCOUNT->engine(), SIGNAL( incomingListedChan( const QString &, uint, const QString & ) ),
-		this, SLOT( slotChannelListed( const QString &, uint, const QString & ) ) );
+	QObject::connect(engine, SIGNAL(incomingListedChan(const QString &, uint, const QString &)),
+		this, SLOT(slotChannelListed(const QString &, uint, const QString &)));
 
 	actionJoin = 0L;
 	actionModeT = new KToggleAction(i18n("Only Operators Can Change &Topic"), 0, this, SLOT(slotModeChanged()), this );
@@ -60,7 +67,6 @@ IRCChannelContact::IRCChannelContact(IRCContactManager *contactManager, const QS
 	actionHomePage = 0L;
 
 	updateStatus();
-	slotUpdateInfo();
 }
 
 IRCChannelContact::~IRCChannelContact()
@@ -71,22 +77,23 @@ void IRCChannelContact::slotUpdateInfo()
 {
 	/** This woudl be nice, but it generates server errors too often
 
-	if( !manager(false) && onlineStatus() == m_protocol->m_ChannelStatusOnline )
-		MYACCOUNT->engine()->writeMessage( QString::fromLatin1("LIST %1").arg(m_nickName) );
+	if( !manager(Kopete::Contact::CannotCreate) && onlineStatus() == m_protocol->m_ChannelStatusOnline )
+		kircEngine()->writeMessage( QString::fromLatin1("LIST %1").arg(m_nickName) );
 	else
 		setProperty( QString::fromLatin1("channelMembers"), i18n("Members"), manager()->members().count() );
 
 	*/
+	KIRC::Engine *engine = kircEngine();
 
-	if( manager(false) )
+	if (manager(Kopete::Contact::CannotCreate))
 	{
-		setProperty( m_protocol->propChannelMembers, manager()->members().count() );
-		MYACCOUNT->engine()->writeMessage( QString::fromLatin1("WHO %1").arg(m_nickName) );
+		setProperty(m_protocol->propChannelMembers, manager()->members().count());
+		engine->writeMessage(QString::fromLatin1("WHO %1").arg(m_nickName));
 	}
 	else
 	{
-		removeProperty( m_protocol->propChannelMembers );
-		removeProperty( m_protocol->propChannelTopic );
+		removeProperty(m_protocol->propChannelMembers);
+		removeProperty(m_protocol->propChannelTopic);
 	}
 
 	mInfoTimer->start( 45000, true );
@@ -94,27 +101,28 @@ void IRCChannelContact::slotUpdateInfo()
 
 void IRCChannelContact::slotChannelListed( const QString &channel, uint members, const QString &topic )
 {
-	if( !manager(false) && onlineStatus() == m_protocol->m_ChannelStatusOnline
-		&& channel.lower() == m_nickName.lower() )
+	if (!manager(Kopete::Contact::CannotCreate) &&
+		onlineStatus() == m_protocol->m_ChannelStatusOnline &&
+		channel.lower() == m_nickName.lower())
 	{
 		mTopic = topic;
-		setProperty( m_protocol->propChannelMembers, members );
-		setProperty( m_protocol->propChannelTopic, topic );
+		setProperty(m_protocol->propChannelMembers, members);
+		setProperty(m_protocol->propChannelTopic, topic);
 	}
 }
 
 void IRCChannelContact::updateStatus()
 {
-	KIRC::EngineStatus status = MYACCOUNT->engine()->status();
-	switch( status )
+	KIRC::Engine::Status status = kircEngine()->status();
+	switch (status)
 	{
-		case KIRC::Disconnected:
-		case KIRC::Connecting:
-		case KIRC::Authentifying:
+		case KIRC::Engine::Idle:
+		case KIRC::Engine::Connecting:
+		case KIRC::Engine::Authentifying:
 			setOnlineStatus(m_protocol->m_ChannelStatusOffline);
 			break;
-		case KIRC::Connected:
-		case KIRC::Closing:
+		case KIRC::Engine::Connected:
+		case KIRC::Engine::Closing:
 			setOnlineStatus(m_protocol->m_ChannelStatusOnline);
 			break;
 		default:
@@ -122,87 +130,105 @@ void IRCChannelContact::updateStatus()
 	}
 }
 
-void IRCChannelContact::messageManagerDestroyed()
+void IRCChannelContact::chatSessionDestroyed()
 {
-	if(manager(false))
+	if (manager(Kopete::Contact::CannotCreate))
 	{
 		part();
-		KopeteContactPtrList contacts = manager()->members();
+		Kopete::ContactPtrList contacts = manager()->members();
 
 		// remove all the users on the channel
-		for( KopeteContact *c = contacts.first(); c; c = contacts.next() )
+		for (Kopete::Contact *c = contacts.first(); c; c = contacts.next())
 		{
-			if( c->metaContact()->isTemporary() && !static_cast<IRCContact*>(c)->isChatting( manager() ) )
+			if (c->metaContact()->isTemporary() &&
+				!static_cast<IRCContact*>(c)->isChatting(manager()))
 				c->deleteLater();
 		}
 	}
 
-	IRCContact::messageManagerDestroyed();
+	IRCContact::chatSessionDestroyed();
 }
 
 void IRCChannelContact::initConversation()
 {
-	MYACCOUNT->engine()->joinChannel(m_nickName, password());
+	kircEngine()->join(m_nickName, password());
 }
 
 void IRCChannelContact::slotConnectedToServer()
 {
-	setOnlineStatus( m_protocol->m_ChannelStatusOnline );
-	if( manager(false) )
-		MYACCOUNT->engine()->joinChannel(m_nickName, password());
+	setOnlineStatus(m_protocol->m_ChannelStatusOnline);
+	if (manager(Kopete::Contact::CannotCreate))
+		kircEngine()->join(m_nickName, password());
 }
 
 void IRCChannelContact::namesList(const QStringList &nicknames)
 {
+	mInfoTimer->stop();
 	mJoinedNicks += nicknames;
-	if( mJoinedNicks.count() == nicknames.count() )
-		slotAddNicknames();
+	slotAddNicknames();
+}
+
+void IRCChannelContact::endOfNames()
+{
+	setMode(QString::null);
+	slotUpdateInfo();
 }
 
 void IRCChannelContact::slotAddNicknames()
 {
-	if( !manager(false) || mJoinedNicks.isEmpty() )
+	if( !manager(Kopete::Contact::CannotCreate) || mJoinedNicks.isEmpty())
 	{
-		slotUpdateInfo();
-		setMode( QString::null );
 		return;
 	}
 
-	QString nickToAdd = mJoinedNicks.front();
-	QChar firstChar = nickToAdd[0];
-	if( firstChar == '@' || firstChar == '+' )
-		nickToAdd = nickToAdd.remove(0, 1);
+	IRCAccount *account = ircAccount();
 
-	mJoinedNicks.pop_front();
-	IRCContact *user;
+	for( uint i = 0; !mJoinedNicks.isEmpty() && i < NICK_BATCH_LENGTH; ++i )
+	{
+		QString nickToAdd = mJoinedNicks.front();
+		QChar firstChar = nickToAdd[0];
+		if( firstChar == '@' || firstChar == '%' || firstChar == '+' )
+			nickToAdd = nickToAdd.remove(0, 1);
 
-	if ( nickToAdd.lower() != MYACCOUNT->mySelf()->nickName().lower() )
-	{
-		//kdDebug(14120) << k_funcinfo << m_nickName << " NICK: " << nickToAdd << endl;
-		user = MYACCOUNT->contactManager()->findUser( nickToAdd );
-		user->setOnlineStatus( m_protocol->m_UserStatusOnline );
-		manager()->addContact( static_cast<KopeteContact*>(user) , true);
-	}
-	else
-	{
-	        user = MYACCOUNT->mySelf();
+		IRCContact *user;
+
+		if ( nickToAdd.lower() != account->mySelf()->nickName().lower() )
+		{
+			//kdDebug(14120) << k_funcinfo << m_nickName << " NICK: " << nickToAdd << endl;
+			user = account->contactManager()->findUser(nickToAdd);
+			user->setOnlineStatus(m_protocol->m_UserStatusOnline);
+		}
+		else
+		{
+			user = account->mySelf();
+		}
+
+		Kopete::OnlineStatus status;
+		if ( firstChar == '@' || firstChar == '%' )
+			status = m_protocol->m_UserStatusOp;
+		else if( firstChar == '+')
+			status = m_protocol->m_UserStatusVoice;
+		else
+			status = user->onlineStatus();
+
+		if( user != account->mySelf() )
+			manager()->addContact(static_cast<Kopete::Contact*>(user) , status, true);
+		else
+			manager()->setContactOnlineStatus( static_cast<Kopete::Contact*>(user), status );
+
+		mJoinedNicks.pop_front();
 	}
 
-	if ( firstChar == '@' || firstChar == '%' )
-		manager()->setContactOnlineStatus( static_cast<KopeteContact*>(user), m_protocol->m_UserStatusOp );
-	else if( firstChar == '+')
-		manager()->setContactOnlineStatus( static_cast<KopeteContact*>(user), m_protocol->m_UserStatusVoice );
-
-	QTimer::singleShot(0, this, SLOT( slotAddNicknames() ) );
+	QTimer::singleShot( 0, this, SLOT( slotAddNicknames() ) );
 }
 
 void IRCChannelContact::channelTopic(const QString &topic)
 {
 	mTopic = topic;
 	setProperty( m_protocol->propChannelTopic, mTopic );
-	manager()->setDisplayName( caption() );
-	KopeteMessage msg((KopeteContact*)this, mMyself, i18n("Topic for %1 is %2").arg(m_nickName).arg(mTopic),
-		KopeteMessage::Internal, KopeteMessage::RichText, KopeteMessage::Chat);
+	manager()->setDisplayName(caption());
+	Kopete::Message msg((Kopete::Contact*)this, mMyself, i18n("Topic for %1 is %2").arg(m_nickName).arg(mTopic),
+	                    Kopete::Message::Internal, Kopete::Message::RichText, CHAT_VIEW);
 	appendMessage(msg);
 }
 
@@ -214,84 +240,92 @@ void IRCChannelContact::channelHomePage(const QString &url)
 
 void IRCChannelContact::join()
 {
-	if ( !manager(false) && onlineStatus().status() == KopeteOnlineStatus::Online )
+	if (!manager(Kopete::Contact::CannotCreate) &&
+		onlineStatus().status() == Kopete::OnlineStatus::Online)
 	{
 		kdDebug() << k_funcinfo << "My nickname:" << m_nickName << endl;
-		kdDebug() << k_funcinfo << "My manager:" << manager(false) << endl;
-		if( manager(false) )
-			kdDebug() << k_funcinfo << "My view:" << manager(false)->view(false) << endl;
+		kdDebug() << k_funcinfo << "My manager:" << manager(Kopete::Contact::CannotCreate) << endl;
+		if( manager(Kopete::Contact::CannotCreate) )
+			kdDebug() << k_funcinfo << "My view:" << manager(Kopete::Contact::CannotCreate)->view(false) << endl;
 		startChat();
 	}
 }
 
 void IRCChannelContact::part()
 {
-	if( manager(false) )
-		MYACCOUNT->engine()->partChannel( m_nickName, MYACCOUNT->defaultPart() );
+	if (manager(Kopete::Contact::CannotCreate))
+	  kircEngine()->part(m_nickName, ircAccount()->defaultPart());
 }
 
 void IRCChannelContact::slotIncomingUserIsAway( const QString &nick, const QString & )
 {
-	if( nick.lower() == MYACCOUNT->mySelf()->nickName().lower() )
+	IRCAccount *account = ircAccount();
+
+	if( nick.lower() == account->mySelf()->nickName().lower() )
 	{
-		IRCUserContact *c = MYACCOUNT->mySelf();
-		if( manager(false) && manager()->members().contains( c ) )
+		IRCUserContact *c = account->mySelf();
+		if (manager(Kopete::Contact::CannotCreate) && manager()->members().contains(c))
 		{
-			KopeteOnlineStatus status = manager()->contactOnlineStatus( c );
-			if( status == m_protocol->m_UserStatusOp )
-				manager()->setContactOnlineStatus( c, m_protocol->m_UserStatusOpAway );
-			else if( status == m_protocol->m_UserStatusOpAway )
-				manager()->setContactOnlineStatus( c, m_protocol->m_UserStatusOp );
-			else if( status == m_protocol->m_UserStatusVoice )
-				manager()->setContactOnlineStatus( c, m_protocol->m_UserStatusVoiceAway );
-			else if( status == m_protocol->m_UserStatusVoiceAway )
-				manager()->setContactOnlineStatus( c, m_protocol->m_UserStatusVoice );
-			else if( status == m_protocol->m_UserStatusAway )
-				manager()->setContactOnlineStatus( c, m_protocol->m_UserStatusOnline );
+			Kopete::OnlineStatus status = manager()->contactOnlineStatus(c);
+			if (status == m_protocol->m_UserStatusOp)
+				manager()->setContactOnlineStatus(c, m_protocol->m_UserStatusOpAway );
+			else if (status == m_protocol->m_UserStatusOpAway)
+				manager()->setContactOnlineStatus(c, m_protocol->m_UserStatusOp);
+			else if (status == m_protocol->m_UserStatusVoice)
+				manager()->setContactOnlineStatus(c, m_protocol->m_UserStatusVoiceAway);
+			else if (status == m_protocol->m_UserStatusVoiceAway)
+				manager()->setContactOnlineStatus(c, m_protocol->m_UserStatusVoice);
+			else if (status == m_protocol->m_UserStatusAway)
+				manager()->setContactOnlineStatus(c, m_protocol->m_UserStatusOnline);
 			else
-				manager()->setContactOnlineStatus( c, m_protocol->m_UserStatusAway );
+				manager()->setContactOnlineStatus(c, m_protocol->m_UserStatusAway);
 		}
 	}
 }
 
 void IRCChannelContact::userJoinedChannel(const QString &nickname)
 {
-	if( nickname.lower() == MYACCOUNT->mySelf()->nickName().lower() )
+	IRCAccount *account = ircAccount();
+
+	if (nickname.lower() == account->mySelf()->nickName().lower())
 	{
 		kdDebug() << k_funcinfo << "Me:" << this << endl;
 		kdDebug() << k_funcinfo << "My nickname:" << m_nickName << endl;
-		kdDebug() << k_funcinfo << "My manager:" << manager(false) << endl;
-		if( manager(false) )
-			kdDebug() << k_funcinfo << "My view:" << manager(false)->view(false) << endl;
+		kdDebug() << k_funcinfo << "My manager:" << manager(Kopete::Contact::CannotCreate) << endl;
+		if (manager(Kopete::Contact::CannotCreate))
+			kdDebug() << k_funcinfo << "My view:" << manager(Kopete::Contact::CannotCreate)->view(false) << endl;
 
-		KopeteMessage msg((KopeteContact *)this, mMyself,
+		Kopete::Message msg((Kopete::Contact *)this, mMyself,
 			i18n("You have joined channel %1").arg(m_nickName),
-			KopeteMessage::Internal, KopeteMessage::PlainText, KopeteMessage::Chat);
-		msg.setImportance( KopeteMessage::Low); //set the importance manualy to low
+			Kopete::Message::Internal, Kopete::Message::PlainText,
+			CHAT_VIEW);
+		msg.setImportance( Kopete::Message::Low); //set the importance manualy to low
 		appendMessage(msg);
 	}
 	else
 	{
-		IRCUserContact *contact = MYACCOUNT->contactManager()->findUser( nickname );
+		IRCUserContact *contact = account->contactManager()->findUser( nickname );
 		contact->setOnlineStatus( m_protocol->m_UserStatusOnline );
-		manager()->addContact((KopeteContact *)contact, true);
-		KopeteMessage msg((KopeteContact *)this, mMyself,
+		manager()->addContact((Kopete::Contact *)contact, true);
+		Kopete::Message msg((Kopete::Contact *)this, mMyself,
 			i18n("User <b>%1</b> joined channel %2").arg(nickname).arg(m_nickName),
-			KopeteMessage::Internal, KopeteMessage::RichText, KopeteMessage::Chat);
-		msg.setImportance( KopeteMessage::Low); //set the importance manualy to low
+			Kopete::Message::Internal, Kopete::Message::RichText, CHAT_VIEW);
+		msg.setImportance( Kopete::Message::Low); //set the importance manualy to low
 		manager()->appendMessage(msg);
 	}
 }
 
 void IRCChannelContact::userPartedChannel(const QString &nickname,const QString &reason)
 {
-	if ( nickname.lower() != MYACCOUNT->engine()->nickName().lower() )
+	IRCAccount *account = ircAccount();
+
+	if (nickname.lower() != account->engine()->nickName().lower())
 	{
-		KopeteContact *c = locateUser( nickname );
+		Kopete::Contact *c = locateUser( nickname );
 		if ( c )
 		{
-			manager()->removeContact( c, KopeteMessage::unescape(reason) );
-			if( c->metaContact()->isTemporary() && !static_cast<IRCContact*>(c)->isChatting( manager(false) ) )
+			manager()->removeContact( c, Kopete::Message::unescape(reason) );
+			if( c->metaContact()->isTemporary() && !static_cast<IRCContact*>(c)->isChatting( manager(Kopete::Contact::CannotCreate) ) )
 				c->deleteLater();
 		}
 	}
@@ -299,21 +333,23 @@ void IRCChannelContact::userPartedChannel(const QString &nickname,const QString
 
 void IRCChannelContact::userKicked(const QString &nick, const QString &nickKicked, const QString &reason)
 {
-	QString r = i18n("Kicked by %1.").arg( nick );
-	if( reason != nick )
+	IRCAccount *account = ircAccount();
+
+	QString r = i18n("Kicked by %1.").arg(nick);
+	if (reason != nick)
 		r.append( i18n(" Reason: %2").arg( reason ) );
 
-	if( nickKicked.lower() != MYACCOUNT->engine()->nickName().lower() )
+	if( nickKicked.lower() != account->engine()->nickName().lower() )
 	{
-		KopeteContact *c = locateUser( nickKicked );
-		if ( c )
+		Kopete::Contact *c = locateUser( nickKicked );
+		if (c)
 		{
 			manager()->removeContact( c, r );
-			KopeteMessage msg( (KopeteContact *)this, mMyself,
-				r, KopeteMessage::Internal, KopeteMessage::PlainText, KopeteMessage::Chat);
-			msg.setImportance(KopeteMessage::Low);
+			Kopete::Message msg( (Kopete::Contact *)this, mMyself,
+					      r, Kopete::Message::Internal, Kopete::Message::PlainText, CHAT_VIEW);
+			msg.setImportance(Kopete::Message::Low);
 			appendMessage(msg);
-			if( c->metaContact()->isTemporary() && !static_cast<IRCContact*>(c)->isChatting( manager(false) ) )
+			if( c->metaContact()->isTemporary() && !static_cast<IRCContact*>(c)->isChatting( manager(Kopete::Contact::CannotCreate) ) )
 				c->deleteLater();
 		}
 	}
@@ -326,28 +362,30 @@ void IRCChannelContact::userKicked(const QString &nick, const QString &nickKicke
 
 void IRCChannelContact::setTopic(const QString &topic)
 {
-	if ( manager(false) )
+	IRCAccount *account = ircAccount();
+
+	if (manager(Kopete::Contact::CannotCreate))
 	{
-		if( manager()->contactOnlineStatus( manager()->user() ) ==
+		if( manager()->contactOnlineStatus( manager()->myself() ) ==
 			m_protocol->m_UserStatusOp || !modeEnabled('t') )
 		{
 			bool okPressed = true;
 			QString newTopic = topic;
 			if( newTopic.isNull() )
 				newTopic = KInputDialog::getText( i18n("New Topic"), i18n("Enter the new topic:"),
-					KopeteMessage::unescape(mTopic), &okPressed, 0L );
+					Kopete::Message::unescape(mTopic), &okPressed, 0L );
 
 			if( okPressed )
 			{
 				mTopic = newTopic;
-				MYACCOUNT->engine()->setTopic( m_nickName, newTopic );
+				kircEngine()->topic(m_nickName, newTopic);
 			}
 		}
 		else
 		{
-			KopeteMessage msg(MYACCOUNT->myServer(), manager()->members(),
+			Kopete::Message msg(account->myServer(), manager()->members(),
 				i18n("You must be a channel operator on %1 to do that.").arg(m_nickName),
-				KopeteMessage::Internal, KopeteMessage::PlainText, KopeteMessage::Chat);
+				Kopete::Message::Internal, Kopete::Message::PlainText, CHAT_VIEW);
 			manager()->appendMessage(msg);
 		}
 	}
@@ -355,30 +393,34 @@ void IRCChannelContact::setTopic(const QString &topic)
 
 void IRCChannelContact::topicChanged(const QString &nick, const QString &newtopic)
 {
+	IRCAccount *account = ircAccount();
+
 	mTopic = newtopic;
 	setProperty( m_protocol->propChannelTopic, mTopic );
 	manager()->setDisplayName( caption() );
-	KopeteMessage msg(MYACCOUNT->myServer(), mMyself,
+	Kopete::Message msg(account->myServer(), mMyself,
 		i18n("%1 has changed the topic to: %2").arg(nick).arg(newtopic),
-		KopeteMessage::Internal, KopeteMessage::RichText, KopeteMessage::Chat);
-	msg.setImportance(KopeteMessage::Low); //set the importance manualy to low
+		Kopete::Message::Internal, Kopete::Message::RichText, CHAT_VIEW);
+	msg.setImportance(Kopete::Message::Low); //set the importance manualy to low
 	appendMessage(msg);
 }
 
 void IRCChannelContact::topicUser(const QString &nick, const QDateTime &time)
 {
-	KopeteMessage msg( MYACCOUNT->myServer(), mMyself,
+	IRCAccount *account = ircAccount();
+
+	Kopete::Message msg(account->myServer(), mMyself,
 		i18n("Topic set by %1 at %2").arg(nick).arg(
 			KGlobal::locale()->formatDateTime(time, true)
-		), KopeteMessage::Internal, KopeteMessage::PlainText, KopeteMessage::Chat);
-	msg.setImportance(KopeteMessage::Low); //set the importance manualy to low
+	), Kopete::Message::Internal, Kopete::Message::PlainText, CHAT_VIEW);
+	msg.setImportance(Kopete::Message::Low); //set the importance manualy to low
 	appendMessage(msg);
 }
 
 void IRCChannelContact::incomingModeChange( const QString &nick, const QString &mode )
 {
-	KopeteMessage msg((KopeteContact *)this, mMyself, i18n("%1 sets mode %2 on  %3").arg(nick).arg(mode).arg(m_nickName), KopeteMessage::Internal, KopeteMessage::PlainText, KopeteMessage::Chat);
-	msg.setImportance( KopeteMessage::Low); //set the importance manualy to low
+	Kopete::Message msg((Kopete::Contact *)this, mMyself, i18n("%1 sets mode %2 on  %3").arg(nick).arg(mode).arg(m_nickName), Kopete::Message::Internal, Kopete::Message::PlainText, CHAT_VIEW);
+	msg.setImportance( Kopete::Message::Low); //set the importance manualy to low
 	appendMessage(msg);
 
 	bool inParams = false;
@@ -419,10 +461,10 @@ void IRCChannelContact::incomingChannelMode( const QString &mode,
 	}
 }
 
-void IRCChannelContact::setMode( const QString &mode )
+void IRCChannelContact::setMode(const QString &mode)
 {
-	if( manager(false) )
-		MYACCOUNT->engine()->changeMode( m_nickName, mode );
+	if (manager(Kopete::Contact::CannotCreate))
+		kircEngine()->mode(m_nickName, mode);
 }
 
 void IRCChannelContact::slotModeChanged()
@@ -470,13 +512,13 @@ void IRCChannelContact::failedChankey()
 	else
 	{
 		setPassword(diaPassword);
-		MYACCOUNT->engine()->joinChannel(m_nickName, password());
+		kircEngine()->join(m_nickName, password());
 	}
 }
 
 void IRCChannelContact::toggleMode( QChar mode, bool enabled, bool update )
 {
-	if( manager(false) )
+	if( manager(Kopete::Contact::CannotCreate) )
 	{
 		switch( mode )
 		{
@@ -562,11 +604,12 @@ QPtrList<KAction> *IRCChannelContact::customContextMenuActions()
 	if( actionHomePage )
 		mCustomActions->append( actionHomePage );
 
-	bool isOperator = manager(false) && ( manager()->contactOnlineStatus( MYACCOUNT->myself() ) == m_protocol->m_UserStatusOp );
+	bool isOperator = manager(Kopete::Contact::CannotCreate) &&
+	    (manager()->contactOnlineStatus(ircAccount()->myself()) == m_protocol->m_UserStatusOp);
 
-	actionJoin->setEnabled( !manager(false) );
-	actionPart->setEnabled( manager(false) );
-	actionTopic->setEnabled( manager(false) && ( !modeEnabled('t') || isOperator ) );
+	actionJoin->setEnabled( !manager(Kopete::Contact::CannotCreate) );
+	actionPart->setEnabled( manager(Kopete::Contact::CannotCreate) );
+	actionTopic->setEnabled( manager(Kopete::Contact::CannotCreate) && ( !modeEnabled('t') || isOperator ) );
 
 	actionModeT->setEnabled(isOperator);
 	actionModeN->setEnabled(isOperator);
@@ -588,9 +631,9 @@ void IRCChannelContact::slotHomepage()
 
 const QString IRCChannelContact::caption() const
 {
-	QString cap = QString::fromLatin1("%1 @ %2").arg(m_nickName).arg(MYACCOUNT->engine()->currentHost());
-		if( !mTopic.isNull() && !mTopic.isEmpty() )
-			cap.append( QString::fromLatin1(" - %1").arg(KopeteMessage::unescape(mTopic)) );
+	QString cap = QString::fromLatin1("%1 @ %2").arg(m_nickName).arg(kircEngine()->currentHost());
+	if(!mTopic.isEmpty())
+		cap.append( QString::fromLatin1(" - %1").arg(Kopete::Message::unescape(mTopic)) );
 
 	return cap;
 }
@@ -599,19 +642,21 @@ void IRCChannelContact::privateMessage(IRCContact *from, IRCContact *to, const Q
 {
 	if(to == this)
 	{
-		KopeteMessage msg(from, manager()->members(), message, KopeteMessage::Inbound,
-			KopeteMessage::RichText, KopeteMessage::Chat);
+		Kopete::Message msg(from, manager()->members(), message, Kopete::Message::Inbound,
+				    Kopete::Message::RichText, CHAT_VIEW);
 		appendMessage(msg);
 	}
 }
 
 void IRCChannelContact::newAction(const QString &from, const QString &action)
 {
-	kdDebug(14120) << k_funcinfo << m_nickName << endl;
+	IRCAccount *account = ircAccount();
 
-	IRCUserContact *f = MYACCOUNT->contactManager()->findUser(from);
-	KopeteMessage msg(f, manager()->members(), action, KopeteMessage::Action,
-		KopeteMessage::RichText, KopeteMessage::Chat);
+	IRCUserContact *f = account->contactManager()->findUser(from);
+	Kopete::Message::MessageDirection dir =
+		(f == account->mySelf()) ? Kopete::Message::Outbound : Kopete::Message::Inbound;
+	Kopete::Message msg(f, manager()->members(), action, dir, Kopete::Message::RichText,
+			    CHAT_VIEW, Kopete::Message::TypeAction);
 	appendMessage(msg);
 }
 
