@@ -250,12 +250,12 @@ void MSNSwitchBoardSocket::slotReadMessage( const QString &msg )
 			QString fontInfo;
 			QString color;
 
-			rx=QRegExp("X-MMS-IM-Format: ([A-Za-z0-9$!*/;\\-]*)");
+			rx=QRegExp("X-MMS-IM-Format: ([^\r\n]*)");
 			rx.search(msg);
 			fontInfo =rx.cap(1);
 
 			color = parseFontAttr(fontInfo, "CO");
-
+			
 			// FIXME: this is so BAAAAAAAAAAAAD :(
 			if (!color.isEmpty() && color.toInt(0,16)!=0)
 			{
@@ -429,6 +429,14 @@ void MSNSwitchBoardSocket::sendTypingMsg( bool isTyping )
 	if( !isTyping )
 		return;
 
+	if ( onlineStatus() != Connected || m_chatMembers.empty())
+	{
+		//we are not yet in a chat.
+		//if we send that command now, we may get disconnected.
+		return;
+	}
+
+
 	QCString message = QString( "MIME-Version: 1.0\r\n"
 		"Content-Type: text/x-msmsgscontrol\r\n"
 		"TypingUser: " + m_myHandle + "\r\n"
@@ -484,7 +492,9 @@ int MSNSwitchBoardSocket::sendMsg( const Kopete::Message &msg )
 
 	if(msg.font() != QFont() )
 	{
-		head += "FN=" + escape( msg.font().family());
+		//It's verry strange that if the font name is bigger than 31 char, the _server_ close the socket and don't deliver the message.
+		//  the real question is why ?   my guess is that MS patched the server because a bug in their client,  but that's just a guess.
+		head += "FN=" + escape( msg.font().family().left(31));
 		head += "; EF=";
 		if(msg.font().bold())
 			head += "B";
@@ -496,8 +506,10 @@ int MSNSwitchBoardSocket::sendMsg( const Kopete::Message &msg )
 			head += "U";
 		head += "; ";
 	}
+	else head+="FN=; EF=; ";
 	/**
 	 * I don't know what to set by default, so i decided to set nothing.  CF Bug 82734
+	 * (but don't forgeto to add an empty FN= and EF= ,  or webmessenger will break. (CF Bug 102371) )
 	  else head+="FN=MS%20Serif; EF=; ";
 	 */
 
@@ -528,7 +540,7 @@ int MSNSwitchBoardSocket::sendMsg( const Kopete::Message &msg )
 		//It's possible to made the opposite client join them, as explained in this MS Word document
 		//http://www.bot-depot.com/forums/index.php?act=Attach&type=post&id=35110
 
-		head+="Message-ID: {7B7B34E6-7A8D-44FF-926C-1799156B58"+QString::number( rand()%10)+QString::number( rand()%10)+"}\r\n";
+		head+="Message-ID: {7B7B34E6-7A8D-44FF-926C-1799156B58"+QString::number( KApplication::random()%10)+QString::number( KApplication::random()%10)+"}\r\n";
 		int len_H=head.utf8().length()+ 14;   //14 is the size of "Chunks: x"
 		//this is the size of each part of the message (excluding the header)
 		int futurmessages_size=1400;  //1400 is a common good size
@@ -725,6 +737,12 @@ void  MSNSwitchBoardSocket::slotEmoticonReceived( KTempFile *file, const QString
 
 void MSNSwitchBoardSocket::cleanQueue()
 {
+	if(m_emoticonTimer)
+	{
+		m_emoticonTimer->stop();
+		m_emoticonTimer->deleteLater();
+		m_emoticonTimer=0L;
+	}
 	kdDebug(14141) << k_funcinfo << m_msgQueue.count() << endl;
 
 	QValueList<const Kopete::Message>::Iterator it_msg;
@@ -755,13 +773,15 @@ Kopete::Message &MSNSwitchBoardSocket::parseCustomEmoticons(Kopete::Message &kms
 			message.replace( QRegExp(QString::fromLatin1( "(^|[\\W\\s]|%1)(%2)(?!\\w)" ).arg(em).arg(em)),
 								QString::fromLatin1("\\1<img align=\"center\" width=\"") +
 			#endif
-			message.replace( es,
+			//match any occurence which is not in a html tag.
+			message.replace( QRegExp(QString::fromLatin1("%1(?![^><]*>)").arg(QRegExp::escape(es))),
 						QString::fromLatin1("<img align=\"center\" width=\"") +
 						QString::number(iconImage.width()) +
 						QString::fromLatin1("\" height=\"") +
 						QString::number(iconImage.height()) +
 						QString::fromLatin1("\" src=\"") + imgPath +
 						QString::fromLatin1("\" title=\"") + es +
+						QString::fromLatin1("\" alt=\"") + es +
 						QString::fromLatin1( "\"/>" ) );
 			kmsg.setBody(message, Kopete::Message::RichText);
 		}
