@@ -54,6 +54,7 @@ YahooAwayDialog::YahooAwayDialog(YahooAccount* account, QWidget *parent, const c
 
 void YahooAwayDialog::setAway(int awayType)
 {
+	awayType = 0;
 	theAccount->setAway(awayType, getSelectedAwayMessage());
 }
 
@@ -299,44 +300,47 @@ void YahooAccount::initConnectionSignals( enum SignalConnectionType sct )
 
 void YahooAccount::connectWithPassword( const QString &passwd )
 {
+	if ( isAway() )
+	{
+		slotGoOnline();
+		return;
+	}
+
+	if ( isConnected() || 
+	     myself()->onlineStatus() == m_protocol->Connecting )
+	{
+		kdDebug(14180) << "Yahoo plugin: Ignoring connect request (already connected)." <<endl;
+		return;
+	
+	}
+
 	if ( passwd.isNull() )
 	{ //cancel the connection attempt
 		static_cast<YahooContact*>( myself() )->setOnlineStatus( m_protocol->Offline );
 		return;
 	}
-
 	
 	QString server = "scs.msg.yahoo.com";
 	int port = 5050;
 
 	YahooSessionManager::manager()->setPager( server, port );
-
 	m_session = YahooSessionManager::manager()->createSession( accountId(), passwd );
-	if(!isConnected() && myself()->onlineStatus() != m_protocol->Connecting)
+	kdDebug(14180) << "Attempting to connect to Yahoo on <" << server << ":" 
+		<< port << ">. user <" << accountId() << ">" << endl;
+	
+	static_cast<YahooContact*>( myself() )->setOnlineStatus( m_protocol->Connecting );
+	if ( m_session && m_session->sessionId() > 0 )
 	{
-		kdDebug(14180) << "Attempting to connect to Yahoo on <" << server << ":" << port << ">. user <" << accountId() << ">" << endl;
-
-		static_cast<YahooContact*>( myself() )->setOnlineStatus( m_protocol->Connecting );
-		if ( m_session && m_session->sessionId() > 0 )
-		{
-
-			initConnectionSignals( MakeConnections );
-			kdDebug(14180) << "Starting the login connection" << endl;
-			m_session->login( initialStatus().internalStatus() );
-
-		}
-		else
-		{
-			kdDebug(14180) << "Couldn't connect!" << endl;
+		initConnectionSignals( MakeConnections );
+		kdDebug(14180) << "Starting the login connection" << endl;
+		m_session->login( initialStatus().internalStatus() );
+	}
+	else
+	{
+		kdDebug(14180) << "Couldn't connect!" << endl;
 			// TODO: message box saying can't connect?
-		}
 	}
-	else if ( isAway() )
-	{	// They're really away, and they want to un-away.
-		slotGoOnline();
-	}
-	else	// ignore
-		kdDebug(14180) << "Yahoo plugin: Ignoring connect request (already connected)." <<endl;
+	
 }
 
 void YahooAccount::disconnect()
@@ -583,21 +587,28 @@ void YahooAccount::slotGotIdentities( const QStringList & /* ids */ )
 	//kdDebug(14180) << k_funcinfo << endl;
 }
 
-void YahooAccount::slotStatusChanged( const QString &who, int stat, const QString &msg, int /* away */)
+void YahooAccount::slotStatusChanged( const QString &who, int stat, const QString &msg, int  away )
 {
 //	kdDebug(14180) << k_funcinfo << endl;
 	Kopete::Contact *kc = contact( who );
 	if ( kc )
 	{
 		Kopete::OnlineStatus newStatus = static_cast<YahooProtocol*>( m_protocol )->statusFromYahoo( stat );
-		if ( newStatus == static_cast<YahooProtocol*>( m_protocol )->Custom )
-			kc->setProperty( m_protocol->awayMessage, msg );
+
+		if( newStatus == static_cast<YahooProtocol*>( m_protocol )->Custom ) {
+			if( away == 0 )
+				newStatus = static_cast<YahooProtocol*>( m_protocol )->Online;
+			kc->setProperty( m_protocol->awayMessage, msg);
+		}
 		else
 			kc->removeProperty( m_protocol->awayMessage );
-
+		
+		if( newStatus == static_cast<YahooProtocol*>( m_protocol )->Idle ) {
+			// TODO: Use the argument 'away' to set the idleTime
+		}
+		
 		kc->setOnlineStatus( newStatus );
 	}
-
 }
 
 void YahooAccount::slotGotIm( const QString &who, const QString &msg, long tm, int /*stat*/)
@@ -625,14 +636,8 @@ void YahooAccount::slotGotIm( const QString &who, const QString &msg, long tm, i
 	
 	kdDebug(14180) << "Message after stripping color codes '" << newMsgText << "'" << endl;
 	
-	newMsgText.replace("<font","</font><font");
-	// if message contained <font>, remove first </font> and add </font> to end
-	int index = newMsgText.find("</font>");
-	if ( index != -1 )
-	{
-		newMsgText.remove(index, 7);
-		newMsgText.append("</font>");
-	}
+	newMsgText.replace( QRegExp("<font([^>]*)size=\"([^>]*)\"([^>]*)>"), 
+	                    QString::fromLatin1("<font\\1style=\"font-size:\\2pt\">" ) );
 	
 	kdDebug(14180) << "Message after fixing font tags '" << newMsgText << "'" << endl;
 	
@@ -751,4 +756,4 @@ void YahooAccount::setOnlineStatus( const Kopete::OnlineStatus& status , const Q
 #include "yahooaccount.moc"
 
 // vim: set noet ts=4 sts=4 sw=4:
-
+//kate: indent-mode csands; tab-width 4;
